@@ -1,13 +1,15 @@
 #!/usr/bin/python3
 
 import os
+
 from debmutate.changelog import (
-    ChangelogEditor,
-    rewrap_changes,
-    any_long_lines,
     WIDTH,
-    )
-from lintian_brush.fixer import report_result, fixed_lintian_tag
+    ChangelogEditor,
+    any_long_lines,
+    rewrap_changes,
+)
+
+from lintian_brush.fixer import fixed_lintian_tag, report_result
 
 updated = []
 
@@ -27,8 +29,10 @@ def wrap_block(changelog, i):
                     continue
                 # Lintian only warns about the first block.
                 fixed_lintian_tag(
-                    'source', 'debian-changelog-line-too-long',
-                    info='line %d' % lineno)
+                    "source",
+                    "debian-changelog-line-too-long",
+                    info="line %d" % lineno,
+                )
         changelog[i]._changes = new_changes
         updated.append(changelog[i].version)
         return True
@@ -36,7 +40,7 @@ def wrap_block(changelog, i):
 
 
 with ChangelogEditor() as updater:
-    if 'CHANGELOG_THOROUGH' not in os.environ:
+    if "CHANGELOG_THOROUGH" not in os.environ:
         wrap_block(updater.changelog, 0)
     else:
         for i in range(len(updater.changelog)):
@@ -44,5 +48,5 @@ with ChangelogEditor() as updater:
 
 
 report_result(
-    'Wrap long lines in changelog entries: %s.' % (
-     ', '.join([str(v) for v in updated])))
+    "Wrap long lines in changelog entries: {}.".format(", ".join([str(v) for v in updated]))
+)
