@@ -16,24 +16,24 @@ from debmutate.watch import (
 )
 
 from lintian_brush.fixer import (
-    source_package_name,
     LintianIssue,
-    report_result,
-    warn,
     diligence,
     net_access_allowed,
-    )
+    report_result,
+    source_package_name,
+    warn,
+)
 from lintian_brush.gpg import fetch_keys
 from lintian_brush.watch import (
-    probe_signature,
     KeyRetrievalFailed,
+    probe_signature,
 )
 
 NUM_KEYS_TO_CHECK = 5
 RELEASES_TO_INSPECT = 5
 
 
-if not os.path.exists('debian/watch'):
+if not os.path.exists("debian/watch"):
     sys.exit(0)
 
 if not net_access_allowed():
@@ -41,8 +41,10 @@ if not net_access_allowed():
 
 has_keys = False
 
-for path in ['debian/upstream/signing-key.asc',
-             'debian/upstream/signing-key.pgp']:
+for path in [
+    "debian/upstream/signing-key.asc",
+    "debian/upstream/signing-key.pgp",
+]:
     if os.path.exists(path):
         has_keys = True
 
@@ -59,32 +61,32 @@ with WatchEditor() as editor:
     used_mangles: List[Optional[str]] = []
     for entry in wf.entries:  # noqa: C901
         try:
-            pgpsigurlmangle = entry.get_option('pgpsigurlmangle')
+            pgpsigurlmangle = entry.get_option("pgpsigurlmangle")
         except KeyError:
             pgpsigurlmangle = None
         if pgpsigurlmangle and has_keys:
             continue
         try:
-            pgpmode = entry.get_option('pgpmode')
+            pgpmode = entry.get_option("pgpmode")
         except KeyError:
-            pgpmode = 'default'
+            pgpmode = "default"
         else:
             if diligence() == 0:
                 continue
-        if pgpmode in ('gittag', 'previous', 'next', 'self'):
+        if pgpmode in ("gittag", "previous", "next", "self"):
             sys.exit(2)
         try:
-            releases = list(sorted(
-                entry.discover(source_package_name()), reverse=True))
+            releases = list(
+                sorted(entry.discover(source_package_name()), reverse=True)
+            )
         except HTTPError as e:
-            warn('HTTP error accessing discovery URL %s: %s.' %
-                 (e.geturl(), e))
+            warn(f"HTTP error accessing discovery URL {e.geturl()}: {e}.")
             sys.exit(0)
         for r in releases[:RELEASES_TO_INSPECT]:
             try:
                 sig_info = probe_signature(
-                    r, pgpsigurlmangle=pgpsigurlmangle,
-                    gpg_context=c)
+                    r, pgpsigurlmangle=pgpsigurlmangle, gpg_context=c
+                )
             except KeyRetrievalFailed:
                 sys.exit(2)
             if sig_info is not None:
@@ -99,30 +101,33 @@ with WatchEditor() as editor:
         active_common_mangles = {x for x in found_common_mangles if x}
         if pgpsigurlmangle is None and active_common_mangles:
             issue = LintianIssue(
-                'source', 'debian-watch-does-not-check-openpgp-signature', ())
+                "source", "debian-watch-does-not-check-openpgp-signature", ()
+            )
             if issue.should_fix():
                 # If only a single mangle is used for all releases
                 # that have signatures, set that.
                 if len(active_common_mangles) == 1:
                     new_mangle = active_common_mangles.pop()
-                    entry.set_option('pgpsigurlmangle', new_mangle)
+                    entry.set_option("pgpsigurlmangle", new_mangle)
                 # If all releases are signed, mandate it.
                 if len(found_common_mangles) == 1:
-                    entry.set_option('pgpmode', 'mangle')
+                    entry.set_option("pgpmode", "mangle")
                     description = "Check upstream PGP signatures."
                 else:
                     # Otherwise, fall back to auto.
-                    entry.set_option('pgpmode', 'auto')
+                    entry.set_option("pgpmode", "auto")
                     description = (
-                        "Opportunistically check upstream PGP signatures.")
+                        "Opportunistically check upstream PGP signatures."
+                    )
                 issue.report_fixed()
         if not has_keys and needed_keys:
             issue = LintianIssue(
-                'source', 'debian-watch-file-pubkey-file-is-missing', ())
+                "source", "debian-watch-file-pubkey-file-is-missing", ()
+            )
             if issue.should_fix():
-                if not os.path.isdir('debian/upstream'):
-                    os.mkdir('debian/upstream')
-                with open('debian/upstream/signing-key.asc', 'wb') as f:
+                if not os.path.isdir("debian/upstream"):
+                    os.mkdir("debian/upstream")
+                with open("debian/upstream/signing-key.asc", "wb") as f:
                     missing_keys = []
                     for fpr in needed_keys:
                         key = c.key_export_minimal(fpr)
@@ -134,14 +139,13 @@ with WatchEditor() as editor:
                         for fpr in missing_keys:
                             key = c.key_export_minimal(fpr)
                             if not key:
-                                warn(f'Unable to export key {fpr}')
+                                warn(f"Unable to export key {fpr}")
                                 sys.exit(0)
                             f.write(key)
 
                 issue.report_fixed()
                 if description is None:
-                    description = "Add upstream signing keys (%s)." % (
-                        ', '.join(missing_keys))
+                    description = "Add upstream signing keys ({}).".format(", ".join(missing_keys))
 
 
 if description:
