@@ -1,13 +1,14 @@
 #!/usr/bin/python3
 
 import sys
+
 from lintian_brush.fixer import (
-    control,
-    report_result,
-    meets_minimum_certainty,
-    is_debcargo_package,
     LintianIssue,
-    )
+    control,
+    is_debcargo_package,
+    meets_minimum_certainty,
+    report_result,
+)
 
 require_root = "no"
 CERTAINTY = "possible"
@@ -20,7 +21,7 @@ if is_debcargo_package():
 
 with control as updater:
     if "Rules-Requires-Root" not in updater.source:
-        issue = LintianIssue(updater.source, 'silent-on-rules-requiring-root')
+        issue = LintianIssue(updater.source, "silent-on-rules-requiring-root")
         if issue.should_fix():
             # TODO: add some heuristics to set require_root = "yes" in common
             # cases, like `debian/rules binary` chown(1)'ing stuff
@@ -28,5 +29,5 @@ with control as updater:
             issue.report_fixed()
 
 report_result(
-    "Set Rules-Requires-Root: %s." % require_root,
-    certainty=CERTAINTY)
+    f"Set Rules-Requires-Root: {require_root}.", certainty=CERTAINTY
+)
