@@ -1,18 +1,19 @@
 #!/usr/bin/python3
 
+import sys
+
 from lintian_brush.fixer import (
     control,
+    fixed_lintian_tag,
     meets_minimum_certainty,
     report_result,
-    fixed_lintian_tag,
-    )
+)
 from lintian_brush.section import (
-    get_name_section_mappings,
     find_expected_section,
-    )
-import sys
+    get_name_section_mappings,
+)
 
-CERTAINTY = 'likely'
+CERTAINTY = "likely"
 
 if not meets_minimum_certainty(CERTAINTY):
     sys.exit(0)
@@ -35,16 +36,23 @@ with control as updater:
         section = binary.get("Section", default_section)
         if expected_section and expected_section != section:
             fixed.append(
-                ('binary package %s' % binary["Package"],
-                 section, expected_section))
+                (
+                    "binary package {}".format(binary["Package"]),
+                    section,
+                    expected_section,
+                )
+            )
             binary["Section"] = expected_section
             fixed_lintian_tag(
-                binary, 'wrong-section-according-to-package-name',
-                info='{} => {}'.format(binary['Package'], expected_section))
+                binary,
+                "wrong-section-according-to-package-name",
+                info="{} => {}".format(binary["Package"], expected_section),
+            )
 
 
 # TODO(jelmer): If there is only a single binary package without section, just
 # set the section of the source package?
 report_result(
-    "Fix sections for %s." % ', '.join(['%s (%s ⇒ %s)' % v for v in fixed]),
-    certainty=CERTAINTY)
+    "Fix sections for {}.".format(", ".join(["{} ({} ⇒ {})".format(*v) for v in fixed])),
+    certainty=CERTAINTY,
+)
