@@ -77,15 +77,8 @@ fn determine_env(
 }
 
 #[pyfunction]
-fn read_desc_file(
-    path: std::path::PathBuf,
-    force_subprocess: Option<bool>,
-) -> PyResult<Vec<Fixer>> {
-    let force_subprocess = force_subprocess.unwrap_or(false);
-    Ok(lintian_brush::read_desc_file(path, force_subprocess)
-        .map_err(|e| PyValueError::new_err(e.to_string()))?
-        .map(|s| Fixer(s))
-        .collect())
+fn default_debianize_cache_dir() -> PyResult<std::path::PathBuf> {
+    debianize::default_debianize_cache_dir().map_err(|e| PyValueError::new_err(e.to_string()))
 }
 
 #[pyfunction]
@@ -123,7 +116,7 @@ fn certainty_sufficient(
 }
 
 #[pyfunction]
-fn min_certainty(certainties: Vec<&str>) -> PyResult<String> {
+fn min_certainty(certainties: Vec<String>) -> PyResult<String> {
     let certainties = certainties
         .iter()
         .map(|c| c.parse().map_err(UnsupportedCertainty::new_err))
@@ -139,7 +132,8 @@ fn resolve_release_codename(name: &str, date: Option<chrono::NaiveDate>) -> Opti
 }
 
 #[pyfunction]
-fn calculate_value(tags: Vec<&str>) -> i32 {
+fn calculate_value(tags: Vec<String>) -> i32 {
+    let tags = tags.iter().map(|s| s.as_str()).collect::<Vec<_>>();
     lintian_brush::calculate_value(tags.as_slice())
 }
 
@@ -239,7 +233,7 @@ pub fn load_resume(py: Python) -> PyResult<PyObject> {
 
 #[pyfunction]
 fn increment_version(mut version: debversion::Version) -> PyResult<debversion::Version> {
-    lintian_brush::increment_version(&mut version);
+    version.increment_debian();
     Ok(version)
 }
 
@@ -418,6 +412,7 @@ fn run_lintian_fixer(
         },
         #[cfg(feature = "python")]
         lintian_brush::FixerError::Python(e) => e.into(),
+        lintian_brush::FixerError::Io(e) => e.into(),
         lintian_brush::FixerError::Other(e) => PyRuntimeError::new_err(e),
         lintian_brush::FixerError::NoChangesAfterOverrides(_o) => NoChanges::new_err((py.None(),)),
         lintian_brush::FixerError::DescriptionMissing => DescriptionMissing::new_err(()),
@@ -435,6 +430,7 @@ fn run_lintian_fixer(
         }
         lintian_brush::FixerError::MemoryError => PyMemoryError::new_err(()),
         lintian_brush::FixerError::TreeError(e) => e.into(),
+        lintian_brush::FixerError::InvalidChangelog(p, s) => ChangelogCreateError::new_err((p, s)),
     })
     .map(|(result, output)| (FixerResult(result), output))
 }
@@ -449,12 +445,13 @@ fn only_changes_last_changelog_block(
     let tree = breezyshim::WorkingTree(tree);
     let basis_tree = Box::new(breezyshim::RevisionTree(basis_tree)) as Box<dyn breezyshim::Tree>;
     let changelog_path = changelog_path.as_path();
-    lintian_brush::only_changes_last_changelog_block(
+    debian_analyzer::changelog::only_changes_last_changelog_block(
         &tree,
-        &basis_tree,
+        basis_tree.as_ref(),
         changelog_path,
         changes.iter(),
     )
+    .map_err(|e| PyValueError::new_err((e.to_string(),)))
 }
 
 #[pyfunction]
@@ -522,16 +519,12 @@ impl ChangelogBehaviour {
 fn guess_update_changelog(
     tree: PyObject,
     path: std::path::PathBuf,
-    cl: Option<PyObject>,
 ) -> pyo3::PyResult<Option<PyObject>> {
     let path = path.as_path();
     Python::with_gil(|py| {
         let tree = breezyshim::tree::WorkingTree(tree);
-        let cl = cl.map(|cl| {
-            debian_analyzer::debianshim::Changelog::from_pyobject(cl.as_ref(py)).unwrap()
-        });
         Ok(
-            debian_analyzer::detect_gbp_dch::guess_update_changelog(&tree, path, cl).map(|cb| {
+            debian_analyzer::detect_gbp_dch::guess_update_changelog(&tree, path, None).map(|cb| {
                 ChangelogBehaviour {
                     update_changelog: cb.update_changelog,
                     explanation: cb.explanation,
@@ -579,10 +572,15 @@ fn update_official_vcs(
 }
 
 #[pyfunction]
-pub fn guess_repository_url(package: &str, maintainer_email: &str) -> Option<String> {
+fn guess_repository_url(package: &str, maintainer_email: &str) -> Option<String> {
     debian_analyzer::salsa::guess_repository_url(package, maintainer_email).map(|u| u.to_string())
 }
 
+#[pyfunction]
+fn find_fixers_dir() -> Option<std::path::PathBuf> {
+    lintian_brush::find_fixers_dir()
+}
+
 #[pymodule]
 fn _lintian_brush_rs(py: Python, m: &PyModule) -> PyResult<()> {
     pyo3_log::init();
@@ -597,12 +595,12 @@ fn _lintian_brush_rs(py: Python, m: &PyModule) -> PyResult<()> {
     m.add_class::<Fixer>()?;
     m.add_class::<ScriptFixer>()?;
     m.add_class::<PythonScriptFixer>()?;
-    m.add_wrapped(wrap_pyfunction!(read_desc_file))?;
     m.add_wrapped(wrap_pyfunction!(available_lintian_fixers))?;
     m.add_wrapped(wrap_pyfunction!(certainty_sufficient))?;
     m.add_wrapped(wrap_pyfunction!(min_certainty))?;
     m.add_wrapped(wrap_pyfunction!(resolve_release_codename))?;
     m.add_wrapped(wrap_pyfunction!(calculate_value))?;
+    m.add_wrapped(wrap_pyfunction!(find_fixers_dir))?;
     m.add(
         "DEFAULT_VALUE_LINTIAN_BRUSH",
         lintian_brush::DEFAULT_VALUE_LINTIAN_BRUSH,
@@ -654,6 +652,7 @@ fn _lintian_brush_rs(py: Python, m: &PyModule) -> PyResult<()> {
     m.add_wrapped(wrap_pyfunction!(guess_update_changelog))?;
     m.add_wrapped(wrap_pyfunction!(update_official_vcs))?;
     m.add_wrapped(wrap_pyfunction!(guess_repository_url))?;
+    m.add_wrapped(wrap_pyfunction!(default_debianize_cache_dir))?;
     m.add("NoVcsLocation", py.get_type::<NoVcsLocation>())?;
     m.add(
         "ConflictingVcsAlreadySpecified",
