@@ -1,7 +1,7 @@
 use breezyshim::branch::{open_containing as open_containing_branch, BranchOpenError};
 use breezyshim::tree::{MutableTree, WorkingTree, WorkingTreeOpenError};
 use clap::Parser;
-use debian_analyzer::debianshim::get_maintainer;
+use debian_changelog::get_maintainer;
 use distro_info::DistroInfo;
 
 use debian_analyzer::svp::{
@@ -168,7 +168,7 @@ fn main() -> Result<(), Box<dyn std::error::Error>> {
         )
         .init();
 
-    breezyshim::init();
+    breezyshim::init().unwrap();
 
     let mut fixers: Vec<_> = lintian_brush::available_lintian_fixers(
         Some(std::path::PathBuf::from(args.fixers.fixers_dir).as_path()),
@@ -271,12 +271,8 @@ fn main() -> Result<(), Box<dyn std::error::Error>> {
         };
         if args.output.identity {
             println!("Committer identity: {}", get_committer(&wt));
-            let (maintainer, email) = get_maintainer();
-            println!(
-                "Changelog identity: {} <{}>",
-                maintainer.as_deref().unwrap_or(""),
-                email.as_deref().unwrap_or("")
-            );
+            let (maintainer, email) = get_maintainer().unwrap_or(("".to_string(), "".to_string()));
+            println!("Changelog identity: {} <{}>", maintainer, email);
             std::process::exit(0);
         }
         let since_revid = wt.last_revision().unwrap();
@@ -423,6 +419,17 @@ fn main() -> Result<(), Box<dyn std::error::Error>> {
                     None,
                 );
             }
+            Err(OverallError::InvalidChangelog(p, s)) => {
+                drop(write_lock);
+                report_fatal(
+                    versions_dict(),
+                    "invalid-changelog",
+                    format!("{}: Invalid changelog: {}", p.display(), s).as_str(),
+                    None,
+                    None,
+                );
+            }
+            #[cfg(feature = "python")]
             Err(OverallError::Python(e)) => {
                 drop(write_lock);
                 report_fatal(
@@ -443,6 +450,26 @@ fn main() -> Result<(), Box<dyn std::error::Error>> {
                     None,
                 );
             }
+            Err(OverallError::IoError(e)) => {
+                drop(write_lock);
+                report_fatal(
+                    versions_dict(),
+                    "io-error",
+                    format!("I/O error: {}", e).as_str(),
+                    None,
+                    None,
+                );
+            }
+            Err(OverallError::Other(e)) => {
+                drop(write_lock);
+                report_fatal(
+                    versions_dict(),
+                    "other-error",
+                    format!("Other error: {}", e).as_str(),
+                    None,
+                    None,
+                );
+            }
             Ok(overall_result) => overall_result,
         };
         std::mem::drop(write_lock);
@@ -506,6 +533,8 @@ fn main() -> Result<(), Box<dyn std::error::Error>> {
                     .unwrap(),
                 &wt,
                 Box::new(std::io::stdout()),
+                None,
+                None,
             )?;
         }
         if svp_enabled() {
@@ -534,13 +563,10 @@ fn versions_dict() -> HashMap<String, String> {
         "lintian-brush".to_string(),
         env!("CARGO_PKG_VERSION").to_string(),
     );
-    pyo3::Python::with_gil(|py| {
-        let breezy = py.import("breezy").unwrap();
-        ret.insert(
-            "breezy".to_string(),
-            breezy.getattr("version_string").unwrap().extract().unwrap(),
-        );
+    let breezy_version = breezyshim::version::version();
+    ret.insert("breezy".to_string(), breezy_version.to_string());
 
+    pyo3::Python::with_gil(|py| {
         let debmutate = py.import("debmutate").unwrap();
         ret.insert(
             "debmutate".to_string(),
