@@ -1,6 +1,4 @@
 use debversion::Version;
-use lazy_regex::regex_replace;
-use pyo3::PyErr;
 use std::collections::{HashMap, HashSet};
 use std::fs::File;
 use std::io::{BufReader, Read};
@@ -13,13 +11,14 @@ use breezyshim::dirty_tracker::{get_dirty_tracker, DirtyTracker};
 use breezyshim::tree::{CommitError, Error as TreeError, Tree, TreeChange, WorkingTree};
 use breezyshim::workspace::{check_clean_tree, reset_tree};
 use breezyshim::RevisionId;
-use debian_analyzer::debianshim::Changelog;
 use debian_analyzer::detect_gbp_dch::{guess_update_changelog, ChangelogBehaviour};
 use debian_analyzer::{
     add_changelog_entry, apply_or_revert, certainty_sufficient, get_committer, min_certainty,
     ApplyError, Certainty, ChangelogError,
 };
+use debian_changelog::ChangeLog;
 
+#[cfg(feature = "python")]
 pub mod py;
 
 #[derive(Clone, PartialEq, Eq, Debug, serde::Serialize, serde::Deserialize)]
@@ -166,7 +165,6 @@ impl TryFrom<&str> for LintianIssue {
 }
 
 #[derive(Clone, PartialEq, Eq, Debug, serde::Serialize, serde::Deserialize)]
-#[pyo3::pyclass]
 pub struct FixerResult {
     pub description: String,
     pub certainty: Option<Certainty>,
@@ -462,6 +460,8 @@ impl Fixer for PythonScriptFixer {
             diligence.unwrap_or(0),
         );
 
+        pyo3::prepare_freethreaded_python();
+
         use pyo3::import_exception;
         use pyo3::prelude::*;
         use pyo3::types::PyDict;
@@ -596,6 +596,7 @@ pub enum FixerError {
     NotCertainEnough(Certainty, Option<Certainty>, Vec<LintianIssue>),
     NotDebianPackage(std::path::PathBuf),
     DescriptionMissing,
+    InvalidChangelog(std::path::PathBuf, String),
     ScriptNotFound(std::path::PathBuf),
     OutputParseError(OutputParseError),
     OutputDecodeError(std::string::FromUtf8Error),
@@ -610,15 +611,25 @@ pub enum FixerError {
     #[cfg(feature = "python")]
     Python(pyo3::PyErr),
     MemoryError,
+    Io(std::io::Error),
     TreeError(TreeError),
     Other(String),
 }
 
+impl From<debian_changelog::Error> for FixerError {
+    fn from(e: debian_changelog::Error) -> Self {
+        match e {
+            debian_changelog::Error::Io(e) => FixerError::Io(e),
+            debian_changelog::Error::Parse(e) => FixerError::ChangelogCreate(e.to_string()),
+        }
+    }
+}
+
 impl From<ChangelogError> for FixerError {
     fn from(e: ChangelogError) -> Self {
         match e {
             ChangelogError::NotDebianPackage(path) => FixerError::NotDebianPackage(path),
-            ChangelogError::Python(e) => FixerError::Python(e),
+            ChangelogError::Python(e) => FixerError::Other(e.to_string()),
         }
     }
 }
@@ -666,6 +677,7 @@ impl std::fmt::Display for FixerError {
                 stderr
             ),
             FixerError::Other(s) => write!(f, "{}", s),
+            #[cfg(feature = "python")]
             FixerError::Python(e) => write!(f, "{}", e),
             FixerError::NotDebianPackage(p) => write!(f, "Not a Debian package: {}", p.display()),
             FixerError::DescriptionMissing => {
@@ -679,6 +691,7 @@ impl std::fmt::Display for FixerError {
                 "Not certain enough to fix (actual: {}, minimum : {:?})",
                 actual, minimum
             ),
+            FixerError::Io(e) => write!(f, "IO error: {}", e),
             FixerError::FailedPatchManipulation(p, p2, s) => write!(
                 f,
                 "Failed to manipulate patch {} in {}: {}",
@@ -687,6 +700,9 @@ impl std::fmt::Display for FixerError {
                 s
             ),
             FixerError::TreeError(e) => write!(f, "Tree error: {}", e),
+            FixerError::InvalidChangelog(p, s) => {
+                write!(f, "Invalid changelog {}: {}", p.display(), s)
+            }
         }
     }
 }
@@ -823,6 +839,41 @@ pub fn read_desc_file<P: AsRef<std::path::Path>>(
     Ok(fixer_iter)
 }
 
+#[cfg(test)]
+mod read_desc_file_tests {
+    #[test]
+    fn test_empty() {
+        let td = tempfile::tempdir().unwrap();
+        let path = td.path().join("empty.desc");
+        std::fs::write(&path, "").unwrap();
+        assert!(super::read_desc_file(&path, false)
+            .unwrap()
+            .next()
+            .is_none());
+    }
+
+    #[test]
+    fn test_single() {
+        let td = tempfile::tempdir().unwrap();
+        let path = td.path().join("single.desc");
+        std::fs::write(
+            &path,
+            r#"---
+- script: foo.sh
+  lintian-tags:
+  - bar
+  - baz
+"#,
+        )
+        .unwrap();
+        let script_path = td.path().join("foo.sh");
+        std::fs::write(script_path, "#!/bin/sh\n").unwrap();
+        let fixer = super::read_desc_file(&path, false).unwrap().next().unwrap();
+        assert_eq!(fixer.name(), "foo");
+        assert_eq!(fixer.lintian_tags(), vec!["bar", "baz"]);
+    }
+}
+
 fn load_fixer(
     name: String,
     tags: Vec<String>,
@@ -1077,6 +1128,7 @@ pub fn data_file_path(
         return Some(path);
     }
 
+    pyo3::prepare_freethreaded_python();
     #[cfg(feature = "python")]
     match pyo3::Python::with_gil(|py| {
         let pkg_resources = py.import("pkg_resources").unwrap();
@@ -1165,18 +1217,27 @@ pub fn run_lintian_fixer(
                 local_tree.abspath(subpath).unwrap(),
             ));
         }
-        Err(TreeError::Other(e)) => return Err(e.into()),
+        Err(TreeError::Other(e)) => return Err(FixerError::Other(e.to_string())),
     };
 
-    let cl = Changelog::from_reader(r, Some(1))?;
-    let package = cl[0].package();
-    let current_version: Version = if cl[0].distributions() == "UNRELEASED" {
-        cl[0].version().clone()
+    let cl = ChangeLog::read(r)?;
+    let first_entry = if let Some(entry) = cl.entries().next() {
+        entry
     } else {
-        let mut version = cl[0].version().clone();
-        increment_version(&mut version);
-        version
+        return Err(FixerError::InvalidChangelog(
+            local_tree.abspath(subpath).unwrap(),
+            "No entries in changelog".to_string(),
+        ));
     };
+    let package = first_entry.package().unwrap();
+    let current_version: Version =
+        if first_entry.distributions().as_deref().unwrap() == vec!["UNRELEASED"] {
+            first_entry.version().unwrap()
+        } else {
+            let mut version = first_entry.version().unwrap();
+            version.increment_debian();
+            version
+        };
 
     let mut _bt = None;
     let basis_tree: &Box<dyn Tree> = if let Some(basis_tree) = basis_tree {
@@ -1186,13 +1247,17 @@ pub fn run_lintian_fixer(
         _bt.as_ref().unwrap()
     };
 
-    let (mut result, changes, mut specific_files) =
-        match apply_or_revert(local_tree, subpath, basis_tree, dirty_tracker, |basedir| {
+    let (mut result, changes, mut specific_files) = match apply_or_revert(
+        local_tree,
+        subpath,
+        basis_tree.as_ref(),
+        dirty_tracker,
+        |basedir| {
             let compat_release = compat_release.unwrap_or("sid");
             log::debug!("Running fixer {:?}", fixer);
             let result = fixer.run(
                 basedir,
-                package,
+                package.as_str(),
                 &current_version,
                 compat_release,
                 minimum_certainty,
@@ -1217,20 +1282,21 @@ pub fn run_lintian_fixer(
             }
 
             Ok(result)
-        }) {
-            Ok(r) => r,
-            Err(ApplyError::NoChanges(r)) => {
-                return Err(FixerError::NoChangesAfterOverrides(
-                    r.overridden_lintian_issues,
-                ));
-            }
-            Err(ApplyError::TreeError(e)) => {
-                return Err(e.into());
-            }
-            Err(ApplyError::CallbackError(e)) => {
-                return Err(e);
-            }
-        };
+        },
+    ) {
+        Ok(r) => r,
+        Err(ApplyError::NoChanges(r)) => {
+            return Err(FixerError::NoChangesAfterOverrides(
+                r.overridden_lintian_issues,
+            ));
+        }
+        Err(ApplyError::TreeError(e)) => {
+            return Err(e.into());
+        }
+        Err(ApplyError::CallbackError(e)) => {
+            return Err(e);
+        }
+    };
 
     let lines = result.description.split('\n').collect::<Vec<_>>();
     let mut summary = lines[0].to_string();
@@ -1247,7 +1313,7 @@ pub fn run_lintian_fixer(
     {
         let (patch_name, updated_specific_files) = match _upstream_changes_to_patch(
             local_tree,
-            basis_tree,
+            basis_tree.as_ref(),
             dirty_tracker,
             subpath,
             &result
@@ -1259,8 +1325,31 @@ pub fn run_lintian_fixer(
         ) {
             Ok(r) => r,
             Err(e) => {
-                reset_tree(local_tree, Some(basis_tree), Some(subpath), dirty_tracker)?;
-                return Err(FixerError::Python(e));
+                reset_tree(
+                    local_tree,
+                    Some(basis_tree.as_ref()),
+                    Some(subpath),
+                    dirty_tracker,
+                )
+                .map_err(|e| FixerError::Other(e.to_string()))?;
+
+                pyo3::import_exception!(lintian_brush, FailedPatchManipulation);
+
+                pyo3::Python::with_gil(|py| {
+                    if e.is_instance_of::<FailedPatchManipulation>(py) {
+                        use pyo3::PyErrArguments;
+                        let args =
+                            e.arguments(py)
+                                .getattr(py, "args")?
+                                .extract::<(pyo3::PyObject, String, String)>(py)?;
+                        return Err(FixerError::FailedPatchManipulation(
+                            args.0.getattr(py, "basedir")?.extract(py)?,
+                            args.1.into(),
+                            args.2,
+                        ));
+                    }
+                    Err(FixerError::Other(e.to_string()))
+                })?
             }
         };
 
@@ -1269,9 +1358,9 @@ pub fn run_lintian_fixer(
         summary = format!("Add patch {}: {}", patch_name, summary);
     }
 
-    let update_changelog = if only_changes_last_changelog_block(
+    let update_changelog = if debian_analyzer::changelog::only_changes_last_changelog_block(
         local_tree,
-        basis_tree,
+        basis_tree.as_ref(),
         changelog_path.as_path(),
         changes.iter(),
     )? {
@@ -1316,6 +1405,7 @@ pub fn run_lintian_fixer(
         )
         .map_err(|e| match e {
             CommitError::PointlessCommit => FixerError::NoChanges,
+            CommitError::NoWhoami => FixerError::Other("No committer specified".to_string()),
             CommitError::Other(e) => FixerError::Python(e),
         })?;
     result.revision_id = Some(revid);
@@ -1329,11 +1419,15 @@ pub enum OverallError {
     NotDebianPackage(std::path::PathBuf),
     WorkspaceDirty(std::path::PathBuf),
     ChangelogCreate(String),
+    InvalidChangelog(std::path::PathBuf, String),
     TreeError(TreeError),
+    IoError(std::io::Error),
+    Other(String),
     #[cfg(feature = "python")]
     Python(pyo3::PyErr),
 }
 
+#[cfg(feature = "python")]
 impl From<pyo3::PyErr> for OverallError {
     fn from(e: pyo3::PyErr) -> Self {
         OverallError::Python(e)
@@ -1354,7 +1448,12 @@ impl std::fmt::Display for OverallError {
             }
             #[cfg(feature = "python")]
             OverallError::Python(e) => write!(f, "{}", e),
+            OverallError::Other(e) => write!(f, "{}", e),
             OverallError::TreeError(e) => write!(f, "{}", e),
+            OverallError::IoError(e) => write!(f, "{}", e),
+            OverallError::InvalidChangelog(path, e) => {
+                write!(f, "Invalid changelog at {}: {}", path.display(), e)
+            }
         }
     }
 }
@@ -1408,11 +1507,11 @@ pub fn run_lintian_fixers(
 ) -> Result<ManyResult, OverallError> {
     let subpath = subpath.unwrap_or_else(|| std::path::Path::new(""));
     let mut basis_tree = local_tree.basis_tree();
-    check_clean_tree(local_tree, &basis_tree, subpath).map_err(|e| match e {
+    check_clean_tree(local_tree, basis_tree.as_ref(), subpath).map_err(|e| match e {
         breezyshim::workspace::CheckCleanTreeError::WorkspaceDirty(p) => {
             OverallError::WorkspaceDirty(p)
         }
-        breezyshim::workspace::CheckCleanTreeError::Python(e) => OverallError::Python(e),
+        breezyshim::workspace::CheckCleanTreeError::Python(e) => OverallError::Other(e.to_string()),
     })?;
 
     let mut changelog_behaviour = None;
@@ -1436,7 +1535,9 @@ pub fn run_lintian_fixers(
             log::warn!("Too many open files for inotify, not using it.");
             None
         }
-        Err(breezyshim::dirty_tracker::Error::Python(e)) => return Err(e.into()),
+        Err(breezyshim::dirty_tracker::Error::Python(e)) => {
+            return Err(OverallError::Other(e.to_string()))
+        }
     };
     for fixer in fixers {
         pb.set_message(format!("Running fixer {}", fixer.name()));
@@ -1532,6 +1633,9 @@ pub fn run_lintian_fixers(
                 FixerError::TreeError(e) => {
                     return Err(OverallError::TreeError(e));
                 }
+                FixerError::Io(e) => {
+                    return Err(OverallError::IoError(e));
+                }
                 FixerError::NotCertainEnough(actual_certainty, minimum_certainty, _overrides) => {
                     if verbose {
                         let duration = std::time::SystemTime::now().duration_since(start).unwrap();
@@ -1579,6 +1683,7 @@ pub fn run_lintian_fixers(
                     ret.overridden_lintian_issues.extend(os);
                     continue;
                 }
+                #[cfg(feature = "python")]
                 FixerError::Python(ref ep) => {
                     if verbose {
                         log::info!("Fixer {} failed: {}", fixer.name(), ep);
@@ -1593,6 +1698,9 @@ pub fn run_lintian_fixers(
                     ret.failed_fixers.insert(fixer.name(), e.to_string());
                     continue;
                 }
+                FixerError::InvalidChangelog(path, reason) => {
+                    return Err(OverallError::InvalidChangelog(path, reason));
+                }
             },
             Ok((result, summary)) => {
                 if verbose {
@@ -1613,99 +1721,6 @@ pub fn run_lintian_fixers(
     Ok(ret)
 }
 
-/// Check whether the only change in a tree is to the last changelog entry.
-///
-/// # Arguments
-/// * `tree`: Tree to analyze
-/// * `changelog_path`: Path to the changelog file
-/// * `changes`: Changes in the tree
-pub fn only_changes_last_changelog_block<'a>(
-    tree: &WorkingTree,
-    basis_tree: &Box<dyn Tree>,
-    changelog_path: &std::path::Path,
-    changes: impl Iterator<Item = &'a TreeChange>,
-) -> pyo3::PyResult<bool> {
-    let read_lock = tree.lock_read();
-    let basis_lock = basis_tree.lock_read();
-    let mut changes_seen = false;
-    for change in changes {
-        if let Some(path) = change.path.1.as_ref() {
-            if path == std::path::Path::new("") {
-                continue;
-            }
-            if path == changelog_path {
-                changes_seen = true;
-                continue;
-            }
-            if !tree.has_versioned_directories() && changelog_path.starts_with(path) {
-                // Directory leading up to changelog
-                continue;
-            }
-        }
-        // If the change is not in the changelog, it's not just a changelog change
-        return Ok(false);
-    }
-
-    if !changes_seen {
-        // Doesn't change the changelog at all
-        return Ok(false);
-    }
-    let mut new_cl = match tree.get_file(changelog_path) {
-        Ok(f) => Changelog::from_reader(f, None)?,
-        Err(TreeError::NoSuchFile(_)) => {
-            return Ok(false);
-        }
-        Err(TreeError::Other(e)) => {
-            return Err(e);
-        }
-    };
-    let mut old_cl = match basis_tree.get_file(changelog_path) {
-        Ok(f) => Changelog::from_reader(f, None)?,
-        Err(TreeError::NoSuchFile(_)) => {
-            return Ok(true);
-        }
-        Err(TreeError::Other(e)) => {
-            return Err(e);
-        }
-    };
-    if old_cl[0].distributions() != "UNRELEASED" {
-        // Not unreleased
-        return Ok(false);
-    }
-    new_cl.pop_first();
-    old_cl.pop_first();
-    std::mem::drop(read_lock);
-    std::mem::drop(basis_lock);
-    Ok(new_cl.to_string() == old_cl.to_string())
-}
-
-/// Increment a version number.
-///
-/// For native packages, increment the main version number.
-/// For other packages, increment the debian revision.
-///
-/// # Arguments
-///
-///  * `v`: Version to increment (modified in place)
-pub fn increment_version(v: &mut Version) {
-    if v.debian_revision.is_some() {
-        v.debian_revision = v.debian_revision.as_ref().map(|v| {
-            {
-                regex_replace!(r"\d+$", v, |x: &str| (x.parse::<i32>().unwrap() + 1)
-                    .to_string())
-            }
-            .to_string()
-        });
-    } else {
-        v.upstream_version = regex_replace!(r"\d+$", v.upstream_version.as_ref(), |x: &str| (x
-            .parse::<i32>()
-            .unwrap()
-            + 1)
-        .to_string())
-        .to_string();
-    }
-}
-
 #[derive(Debug, Clone, serde::Serialize, serde::Deserialize, Default)]
 pub struct ManyResult {
     #[serde(rename = "applied")]
@@ -1834,15 +1849,16 @@ fn has_non_debian_changes(changes: &[TreeChange], subpath: &std::path::Path) ->
 
 fn _upstream_changes_to_patch(
     local_tree: &WorkingTree,
-    basis_tree: &Box<dyn Tree>,
+    basis_tree: &dyn Tree,
     dirty_tracker: Option<&DirtyTracker>,
     subpath: &std::path::Path,
     patch_name: &str,
     description: &str,
     timestamp: Option<chrono::naive::NaiveDateTime>,
 ) -> pyo3::PyResult<(String, Vec<std::path::PathBuf>)> {
-    use pyo3::conversion::ToPyObject;
+    pyo3::prepare_freethreaded_python();
     pyo3::Python::with_gil(|py| {
+        use pyo3::conversion::ToPyObject;
         let m = py.import("lintian_brush")?;
         let upstream_changes_to_patch = m.getattr("_upstream_changes_to_patch")?;
         upstream_changes_to_patch
@@ -1883,7 +1899,7 @@ pub fn determine_update_changelog(
     let changelog_path = debian_path.join("changelog");
 
     let cl = match local_tree.get_file(changelog_path.as_path()) {
-        Ok(f) => Changelog::from_reader(f, None).unwrap(),
+        Ok(f) => ChangeLog::read(f).unwrap(),
 
         Err(TreeError::NoSuchFile(_)) => {
             // If there's no changelog, then there's nothing to update!
