@@ -18,17 +18,16 @@
 """Utility functions for dealing with changelog files."""
 
 from datetime import datetime
-
-from typing import Optional, Tuple, List
+from typing import List, Optional, Tuple
 
 from breezy.mutabletree import MutableTree
-
 from debmutate.changelog import (
     Changelog,
+)
+from debmutate.changelog import (
     changelog_add_entry as _changelog_add_entry,
 )
 
-
 DEFAULT_URGENCY = "medium"
 
 
@@ -53,8 +52,8 @@ def add_changelog_entry(
     with tree.get_file(path) as f:
         cl = Changelog()
         cl.parse_changelog(
-                f, max_blocks=None, allow_empty_author=True,
-                strict=False)
+            f, max_blocks=None, allow_empty_author=True, strict=False
+        )
         _changelog_add_entry(
             cl,
             summary=summary,
