@@ -17,28 +17,28 @@
 
 """Helper functions for fixers."""
 
+import os
+import sys
 from collections.abc import MutableMapping
+from typing import List, Optional, Tuple, Union
+
 from debmutate.control import ControlEditor
 from debmutate.deb822 import Deb822Paragraph
 from debmutate.vendor import get_vendor_name
-import sys
-from typing import Optional, Tuple, Union, List
+
+from debian.changelog import Version
 
 from . import (
     DEFAULT_MINIMUM_CERTAINTY,
     certainty_sufficient,
 )
 from .lintian_overrides import (
-    get_overrides,
     LintianOverride,
+    get_overrides,
     load_renamed_tags,
 )
 
 
-from debian.changelog import Version
-import os
-
-
 class LintianIssue:
     """Represents a lintian issue."""
 
@@ -80,8 +80,10 @@ class LintianIssue:
 
     def override_exists(self):
         return _override_exists(
-            tag=self.tag, info=self.info, type=self.target[0],
-            package=self.target[1]
+            tag=self.tag,
+            info=self.info,
+            type=self.target[0],
+            package=self.target[1],
         )
 
     def should_fix(self):
@@ -98,16 +100,11 @@ class LintianIssue:
         if self.target[1] is not None:
             ret.append(self.target[1] + " ")
         ret.append(self.target[0])
-        ret.append(": " + self.tag + (' ' + self.info) if self.info else '')
+        ret.append(": " + self.tag + (" " + self.info) if self.info else "")
         return "".join(ret)
 
     def __repr__(self):
-        return "{}(target={!r}, tag={!r}, info={!r})".format(
-            type(self).__name__,
-            self.target,
-            self.tag,
-            self.info,
-        )
+        return f"{type(self).__name__}(target={self.target!r}, tag={self.tag!r}, info={self.info!r})"
 
 
 _fixed_lintian_issues: List[LintianIssue] = []
@@ -134,7 +131,8 @@ def _override_exists(
         if _tag_renames.get(override.tag) == tag:
             tag = override.tag
         if override.matches(
-                package=package, info=info, tag=tag, arch=arch, type=type):
+            package=package, info=info, tag=tag, arch=arch, type=type
+        ):
             return True
     return False
 
@@ -160,8 +158,9 @@ def reset() -> None:
     _overriden_issues = []
 
 
-def report_result(description=None, certainty=None, patch_name=None,
-                  details=None):
+def report_result(
+    description=None, certainty=None, patch_name=None, details=None
+):
     """Report the result of a fixer.
 
     Args:
@@ -174,19 +173,18 @@ def report_result(description=None, certainty=None, patch_name=None,
         print(description)
     if details:
         for detail in details:
-            print('+ %s' % detail)
+            print(f"+ {detail}")
     if certainty:
-        print("Certainty: %s" % certainty)
-    fixed_lintian_tags = {
-        issue.tag for issue in _fixed_lintian_issues}
+        print(f"Certainty: {certainty}")
+    fixed_lintian_tags = {issue.tag for issue in _fixed_lintian_issues}
     if fixed_lintian_tags:
-        print("Fixed-Lintian-Tags: %s" % ", ".join(sorted(fixed_lintian_tags)))
+        print("Fixed-Lintian-Tags: {}".format(", ".join(sorted(fixed_lintian_tags))))
     if _overriden_issues:
         print("Overridden-Lintian-Issues:")
         for issue in _overriden_issues:
-            print(' ' + str(issue))
+            print(" " + str(issue))
     if patch_name:
-        print("Patch-Name: %s" % patch_name)
+        print(f"Patch-Name: {patch_name}")
     reset()
 
 
@@ -216,7 +214,7 @@ def package_is_native():
 def meets_minimum_certainty(certainty):
     return certainty_sufficient(
         certainty,
-        os.environ.get("MINIMUM_CERTAINTY", DEFAULT_MINIMUM_CERTAINTY)
+        os.environ.get("MINIMUM_CERTAINTY", DEFAULT_MINIMUM_CERTAINTY),
     )
 
 
@@ -229,7 +227,7 @@ def opinionated():
 
 
 def warn(msg):
-    sys.stderr.write("%s\n" % msg)
+    sys.stderr.write(f"{msg}\n")
 
 
 def diligence():
@@ -241,12 +239,13 @@ def source_package_name():
 
 
 def is_debcargo_package():
-    return os.path.exists('debian/debcargo.toml')
+    return os.path.exists("debian/debcargo.toml")
 
 
 if is_debcargo_package():
     from debmutate.debcargo import DebcargoControlShimEditor
-    control = DebcargoControlShimEditor.from_debian_dir('debian')
+
+    control = DebcargoControlShimEditor.from_debian_dir("debian")
 else:
     control = ControlEditor()
 
@@ -266,7 +265,7 @@ def linenos_to_ranges(linenos):
             ret.append("%d-%d" % (r[0], r[-1]))
 
     for lineno in linenos:
-        if not cur_range or cur_range[-1] == lineno-1:
+        if not cur_range or cur_range[-1] == lineno - 1:
             cur_range.append(lineno)
         else:
             finalize_range(cur_range)
@@ -277,7 +276,7 @@ def linenos_to_ranges(linenos):
 
 
 def shorten_path(path):
-    ps = path.split('/')
-    if ps[0] == 'debian':
-        ps[0] = 'd'
-    return '/'.join(ps)
+    ps = path.split("/")
+    if ps[0] == "debian":
+        ps[0] = "d"
+    return "/".join(ps)
