@@ -33,37 +33,34 @@ __all__ = [
 ]
 
 import contextlib
+import os
 from datetime import datetime
 from email.message import Message
 from io import BytesIO
-import os
-from typing import Optional, Tuple, List
+from typing import List, Optional, Tuple
 
-from breezy.diff import show_diff_trees
-from breezy import osutils
-from breezy.commit import filter_excluded
 import breezy.bzr  # noqa: F401
 import breezy.git  # noqa: F401
+from breezy import osutils
+from breezy.commit import filter_excluded
+from breezy.diff import show_diff_trees
 from breezy.errors import NotBranchError
-from breezy.transport import NoSuchFile
-
 from breezy.patches import (
-    parse_patches,
-    apply_patches,
     PatchSyntax,
+    apply_patches,
+    parse_patches,
 )
+from breezy.transport import NoSuchFile
 from breezy.tree import Tree
 from breezy.workingtree import WorkingTree
-
-from debian.changelog import Changelog
-
+from breezy.workspace import reset_tree
 from debmutate.patch import (
     QuiltSeriesEditor,
-    read_quilt_series,
     find_common_patch_suffix,
+    read_quilt_series,
 )
 
-from . import reset_tree
+from debian.changelog import Changelog
 
 # TODO(jelmer): Use debmutate version
 DEFAULT_DEBIAN_PATCHES_DIR = "debian/patches"
@@ -82,10 +79,10 @@ def find_patch_base(tree):
         package = cl.package
         upstream_version = cl.version.upstream_version
     possible_tags = [
-        "upstream-%s" % upstream_version,
-        "upstream/%s" % upstream_version,
-        "%s" % upstream_version,
-        "v%s" % upstream_version,
+        f"upstream-{upstream_version}",
+        f"upstream/{upstream_version}",
+        f"{upstream_version}",
+        f"v{upstream_version}",
         f"{package}-{upstream_version}",
     ]
     tags = tree.branch.tags.get_tag_dict()
@@ -106,13 +103,13 @@ def find_patches_branch(tree):
     """
     if tree.branch.name is None:
         return None
-    branch_name = "patch-queue/%s" % tree.branch.name
+    branch_name = f"patch-queue/{tree.branch.name}"
     with contextlib.suppress(NotBranchError):
         return tree.branch.controldir.open_branch(branch_name)
     if tree.branch.name == "master":
         branch_name = "patched"
     else:
-        branch_name = "patched-%s" % tree.branch.name
+        branch_name = f"patched-{tree.branch.name}"
     with contextlib.suppress(NotBranchError):
         return tree.branch.controldir.open_branch(branch_name)
     return None
@@ -267,8 +264,8 @@ def tree_non_patches_changes(tree, patches_directory):
         tree, patches
     ) as upstream_patches_tree, AppliedPatches(tree, patches) as patches_tree:
         for change in filter_excluded(
-            patches_tree.iter_changes(
-                upstream_patches_tree), exclude=["debian"]
+            patches_tree.iter_changes(upstream_patches_tree),
+            exclude=["debian"],
         ):
             path = change.path[1]
             if path == "":
