@@ -17,19 +17,19 @@
 
 """Tests for lintian_brush fixers."""
 
-from debian.changelog import Changelog
 import os
-import subprocess
 import shutil
+import subprocess
 import sys
 import tempfile
 import unittest
 
+from debian.changelog import Changelog
 from lintian_brush import (
     available_lintian_fixers,
+    increment_version,
     parse_script_fixer_output,
     select_fixers,
-    increment_version,
 )
 from lintian_brush.lintian_overrides import (
     load_renamed_tags,
@@ -56,8 +56,10 @@ class FixerTestCase(unittest.TestCase):
             return [name for name in names if name.endswith("~")]
 
         shutil.copytree(
-            os.path.join(self._path, "in"), self._testdir, symlinks=True,
-            ignore=ignore
+            os.path.join(self._path, "in"),
+            self._testdir,
+            symlinks=True,
+            ignore=ignore,
         )
 
     def id(self):
@@ -73,7 +75,10 @@ class FixerTestCase(unittest.TestCase):
                 reason = f.read()  # noqa: F841
             unittest.expectedFailure(self)
             return
-        env = dict(os.environ.items())
+        env = {}
+        for key in ["PATH"]:
+            if key in os.environ:
+                env[key] = os.environ[key]
         cl_path = os.path.join(self._testdir, "debian/changelog")
         if os.path.exists(cl_path):
             with open(cl_path, "rb") as f:
@@ -82,15 +87,16 @@ class FixerTestCase(unittest.TestCase):
                 current_version = cl.version
             else:
                 current_version = cl.version
-            increment_version(current_version)
+            current_version = increment_version(current_version)
         else:
             current_version = "1.0-1"
         env["CURRENT_VERSION"] = str(current_version)
         env["NET_ACCESS"] = "disallow"
         env["MINIMUM_CERTAINTY"] = "possible"
-        env["PYTHONPATH"] = ':'.join(
+        env["PYTHONPATH"] = ":".join(
             [os.path.dirname(os.path.dirname(os.path.dirname(__file__)))]
-            + sys.path)
+            + sys.path
+        )
         env_path = os.path.join(self._path, "env")
         if os.path.exists(env_path):
             with open(env_path) as f:
@@ -98,11 +104,14 @@ class FixerTestCase(unittest.TestCase):
                     key, value = line.rstrip("\n").split("=")
                     env[key] = value
         p = subprocess.Popen(
-            self._fixer.script_path, cwd=self._testdir, stdout=subprocess.PIPE,
-            env=env
+            self._fixer.script_path,
+            cwd=self._testdir,
+            stdout=subprocess.PIPE,
+            stderr=subprocess.PIPE,
+            env=env,
         )
         (stdout, err) = p.communicate(b"")
-        self.assertEqual(p.returncode, 0)
+        self.assertEqual(p.returncode, 0, f"Unexpected exit code {p.returncode}: {err.decode()}")
         out_path = os.path.join(self._path, "out")
         p = subprocess.Popen(
             [
@@ -120,10 +129,10 @@ class FixerTestCase(unittest.TestCase):
         )
         (diff, stderr) = p.communicate(b"")
         self.assertIn(
-            p.returncode, (0, 1),
-            "Unexpected exit code %d" % p.returncode)
+            p.returncode, (0, 1), "Unexpected exit code %d" % p.returncode
+        )
         if diff.decode() != "":
-            raise AssertionError("unexpected output: %s" % diff.decode())
+            raise AssertionError(f"unexpected output: {diff.decode()}")
         self.assertMultiLineEqual(diff.decode(), "")
 
         if (
@@ -134,14 +143,10 @@ class FixerTestCase(unittest.TestCase):
             result = parse_script_fixer_output(stdout.decode())
             self.assertTrue(
                 set(result.fixed_lintian_tags).issubset(
-                    self._fixer.lintian_tags),
-                "fixer %s claims to fix tags (%r) not declared "
-                "in index.desc (%r)"
-                % (
-                    self._fixer_name,
-                    result.fixed_lintian_tags,
-                    self._fixer.lintian_tags,
+                    self._fixer.lintian_tags
                 ),
+                f"fixer {self._fixer_name} claims to fix tags ({result.fixed_lintian_tags!r}) not declared "
+                f"in index.desc ({self._fixer.lintian_tags!r})",
             )
         else:
             check_message = False
@@ -160,7 +165,7 @@ class SaneFixerTests(unittest.TestCase):
         return f"{__name__}.{self.fixer.name}.sane"
 
     def __str__(self):
-        return "fixer sanity test: %s" % (self.fixer.name)
+        return f"fixer sanity test: {self.fixer.name}"
 
     def __init__(self, fixer):
         self.fixer = fixer
@@ -169,14 +174,15 @@ class SaneFixerTests(unittest.TestCase):
     def runTest(self):
         self.assertTrue(
             os.path.exists(self.fixer.script_path),
-            "Script %s missing" % self.fixer.script_path,
+            f"Script {self.fixer.script_path} missing",
         )
 
         renames = load_renamed_tags()
         for tag in self.fixer.lintian_tags:
             self.assertNotIn(
-                tag, renames,
-                f"Tag {tag} has been renamed to {renames.get(tag)}"
+                tag,
+                renames,
+                f"Tag {tag} has been renamed to {renames.get(tag)}",
             )
 
 
@@ -216,17 +222,21 @@ if __name__ == "__main__":
         help="Fixer for which to run tests.",
     )
     parser.add_argument(
-        "--exclude", type=str, action="append", help="Exclude a fixer.")
+        "--exclude", type=str, action="append", help="Exclude a fixer."
+    )
     args = parser.parse_args()
 
     fixers = list(available_lintian_fixers())
     if args.fixer:
         try:
             fixers = select_fixers(
-                fixers, names=args.fixer, exclude=args.exclude)
+                fixers, names=args.fixer, exclude=args.exclude
+            )
         except KeyError as e:
-            print("Selected fixer %s does not exist." % (
-                e.args[0]), file=sys.stderr)
+            print(
+                f"Selected fixer {e.args[0]} does not exist.",
+                file=sys.stderr,
+            )
             sys.exit(0)
 
     suite = unittest.TestSuite()
