@@ -26,7 +26,6 @@ from breezy.tests import (
 from debian.changelog import (
     ChangelogCreateError,
 )
-
 from lintian_brush.changelog import (
     add_changelog_entry,
 )
@@ -350,7 +349,8 @@ lintian-brush (0.35) unstable; urgency=medium
         self.overrideEnv("DEBEMAIL", "joe@example.com")
         try:
             add_changelog_entry(
-                tree, "debian/changelog", ["And this one is new."])
+                tree, "debian/changelog", ["And this one is new."]
+            )
         except ChangelogCreateError:
             self.skipTest(
                 "python-debian does not allow serializing changelog "
@@ -393,7 +393,8 @@ lintian-brush (0.35) unstable; urgency=medium
         self.overrideEnv("DEBEMAIL", "joe@example.com")
         try:
             add_changelog_entry(
-                tree, "debian/changelog", ["And this one is new."])
+                tree, "debian/changelog", ["And this one is new."]
+            )
         except ChangelogCreateError:
             self.skipTest(
                 "python-debian does not allow serializing changelog "
