@@ -17,15 +17,15 @@
 
 """Tests for lintian_brush.detect_gbp_dch."""
 
-from ..detect_gbp_dch import (
-    guess_update_changelog,
-    ChangelogBehaviour,
-)
-
 from breezy.tests import (
     TestCaseWithTransport,
 )
 
+from ..detect_gbp_dch import (
+    ChangelogBehaviour,
+    guess_update_changelog,
+)
+
 
 def make_changelog(entries):
     return (
@@ -33,7 +33,7 @@ def make_changelog(entries):
 lintian-brush (0.1) UNRELEASED; urgency=medium
 
 """
-        + "".join(["  * %s\n" % entry for entry in entries])
+        + "".join([f"  * {entry}\n" for entry in entries])
         + """
 
  -- Jelmer Vernooij <jelmer@debian.org>  Sat, 13 Oct 2018 11:21:39 +0100
@@ -47,31 +47,42 @@ class GuessUpdateChangelogTests(TestCaseWithTransport):
         self.assertEqual(
             ChangelogBehaviour(
                 True,
-                'Assuming changelog needs to be updated, '
-                'since it is always changed together '
-                'with other files in the tree.'),
-            guess_update_changelog(tree, "debian"))
+                "Assuming changelog needs to be updated, "
+                "since it is always changed together "
+                "with other files in the tree.",
+            ),
+            guess_update_changelog(tree, "debian"),
+        )
 
     def test_custom_path(self):
         tree = self.make_branch_and_tree(".")
-        self.assertEqual(ChangelogBehaviour(
-            True,
-            'Assuming changelog needs to be updated, '
-            'since it is always changed together '
-            'with other files in the tree.'),
-            guess_update_changelog(tree, "debian"))
-        self.assertEqual(ChangelogBehaviour(
-            True,
-            'assuming changelog needs to be updated since '
-            'gbp dch only supports a debian '
-            'directory in the root of the repository'),
-            guess_update_changelog(tree, ""))
-        self.assertEqual(ChangelogBehaviour(
-            True,
-            'assuming changelog needs to be updated since '
-            'gbp dch only supports a debian '
-            'directory in the root of the repository'),
-            guess_update_changelog(tree, "lala/debian"))
+        self.assertEqual(
+            ChangelogBehaviour(
+                True,
+                "Assuming changelog needs to be updated, "
+                "since it is always changed together "
+                "with other files in the tree.",
+            ),
+            guess_update_changelog(tree, "debian"),
+        )
+        self.assertEqual(
+            ChangelogBehaviour(
+                True,
+                "assuming changelog needs to be updated since "
+                "gbp dch only supports a debian "
+                "directory in the root of the repository",
+            ),
+            guess_update_changelog(tree, ""),
+        )
+        self.assertEqual(
+            ChangelogBehaviour(
+                True,
+                "assuming changelog needs to be updated since "
+                "gbp dch only supports a debian "
+                "directory in the root of the repository",
+            ),
+            guess_update_changelog(tree, "lala/debian"),
+        )
 
     def test_gbp_conf_dch(self):
         tree = self.make_branch_and_tree(".")
@@ -82,6 +93,7 @@ class GuessUpdateChangelogTests(TestCaseWithTransport):
                     "debian/gbp.conf",
                     """\
 [dch]
+pristine-tar = False
 """,
                 ),
             ]
@@ -167,16 +179,21 @@ blah (0.20.1) unstable; urgency=medium
         changelog_entries = ["initial release"]
         for i in range(20):
             builder.build_snapshot(
-                None, [("modify", ("upstream", b"upstream %d" % i))],
-                message="Upstream"
+                None,
+                [("modify", ("upstream", b"upstream %d" % i))],
+                message="Upstream",
             )
             changelog_entries.append("next entry %d" % i)
             builder.build_snapshot(
                 None,
                 [
-                    ("modify", (
-                        "debian/changelog",
-                        make_changelog(changelog_entries))),
+                    (
+                        "modify",
+                        (
+                            "debian/changelog",
+                            make_changelog(changelog_entries),
+                        ),
+                    ),
                     ("modify", ("debian/control", b"next %d" % i)),
                 ],
                 message="Next",
@@ -219,13 +236,18 @@ blah (0.20.1) unstable; urgency=medium
         for i in range(20):
             changelog_entries.append("next entry %d" % i)
             builder.build_snapshot(
-                None, [("modify", ("debian/control", b"next %d" % i))],
-                message="Next\n"
+                None,
+                [("modify", ("debian/control", b"next %d" % i))],
+                message="Next\n",
             )
         builder.build_snapshot(
             None,
-            [("modify",
-                ("debian/changelog", make_changelog(changelog_entries)))]
+            [
+                (
+                    "modify",
+                    ("debian/changelog", make_changelog(changelog_entries)),
+                )
+            ],
         )
         changelog_entries.append("final entry")
         builder.build_snapshot(
@@ -233,8 +255,12 @@ blah (0.20.1) unstable; urgency=medium
         )
         builder.build_snapshot(
             None,
-            [("modify",
-                ("debian/changelog", make_changelog(changelog_entries)))]
+            [
+                (
+                    "modify",
+                    ("debian/changelog", make_changelog(changelog_entries)),
+                )
+            ],
         )
         builder.finish_series()
         branch = builder.get_branch()
@@ -254,7 +280,7 @@ blah (0.20.1) unstable; urgency=medium
         builder.build_snapshot(
             None,
             [("add", ("", None, "directory", ""))],
-            message="Git-Dch: ignore\n"
+            message="Git-Dch: ignore\n",
         )
         branch = builder.get_branch()
         tree = branch.controldir.create_workingtree()
@@ -288,8 +314,8 @@ blah (0.20.1) UNRELEASED; urgency=medium
         self.assertEqual(
             ChangelogBehaviour(
                 False,
-                'assuming changelog does not need to be '
-                'updated since it is the inaugural unreleased entry'
+                "assuming changelog does not need to be "
+                "updated since it is the inaugural unreleased entry",
             ),
             guess_update_changelog(tree, "debian"),
         )
@@ -321,8 +347,8 @@ blah (0.20.1) unstable; urgency=medium
         self.assertEqual(
             ChangelogBehaviour(
                 False,
-                'last changelog entry warns changelog is generated '
-                'at release time',
+                "last changelog entry warns changelog is generated "
+                "at release time",
             ),
             guess_update_changelog(tree, "debian"),
         )
@@ -375,8 +401,8 @@ blah (0.20.1) unstable; urgency=medium
         self.assertEqual(
             ChangelogBehaviour(
                 False,
-                'Assuming changelog does not need to be updated, '
-                'since it never uses UNRELEASED entries'
+                "Assuming changelog does not need to be updated, "
+                "since it never uses UNRELEASED entries",
             ),
             guess_update_changelog(tree, "debian"),
         )
