@@ -46,7 +46,6 @@ from lintian_brush import (
     available_lintian_fixers,
     certainty_sufficient,
     certainty_to_confidence,
-    confidence_to_certainty,
     get_committer,
     increment_version,
     min_certainty,
@@ -102,8 +101,10 @@ class AvailableLintianFixersTest(TestCaseWithTransport):
         )
         self.assertEqual(
             [["i-fix-a-tag"], ["i-fix-another-tag", "no-extension"]],
-            [fixer.lintian_tags
-             for fixer in available_lintian_fixers("fixers")],
+            [
+                fixer.lintian_tags
+                for fixer in available_lintian_fixers("fixers")
+            ],
         )
 
 
@@ -121,7 +122,6 @@ class DummyFixer:
 
 
 class FailingFixer:
-
     def __init__(self, name, tags):
         self.name = name
         self.lintian_tags = tags
@@ -184,8 +184,8 @@ Arch: all
         self.assertEqual("certain", result.certainty)
         self.assertEqual(2, tree.branch.revno())
         self.assertEqual(
-            tree.get_file_lines("debian/control")[-1],
-            b"a new line\n")
+            tree.get_file_lines("debian/control")[-1], b"a new line\n"
+        )
 
     def test_simple_modify_too_uncertain(self):
         tree = self.make_test_tree()
@@ -249,7 +249,8 @@ Arch: all
         with tree.lock_write():
             result, summary = run_lintian_fixer(
                 tree,
-                NewFileFixer("new-file", ["some-tag"]), update_changelog=False
+                NewFileFixer("new-file", ["some-tag"]),
+                update_changelog=False,
             )
         self.assertEqual(summary, "Created new file.")
         self.assertIs(None, result.certainty)
@@ -269,7 +270,8 @@ Arch: all
         basis_tree = tree.branch.basis_tree()
         with basis_tree.lock_read():
             self.assertEqual(
-                basis_tree.get_file_text("debian/somefile"), b"test")
+                basis_tree.get_file_text("debian/somefile"), b"test"
+            )
 
     def test_rename_file(self):
         tree = self.make_test_tree()
@@ -289,8 +291,9 @@ Arch: all
         orig_basis_tree = tree.branch.basis_tree()
         with tree.lock_write():
             result, summary = run_lintian_fixer(
-                tree, RenameFileFixer("rename", ["some-tag"]),
-                update_changelog=False
+                tree,
+                RenameFileFixer("rename", ["some-tag"]),
+                update_changelog=False,
             )
         self.assertEqual(summary, "Renamed a file.")
         self.assertIs(None, result.certainty)
@@ -384,10 +387,11 @@ Arch: all
         with basis_tree.lock_read():
             self.assertEqual(
                 basis_tree.get_file_text("debian/patches/series"),
-                b"add-config.patch\n"
+                b"add-config.patch\n",
             )
             lines = basis_tree.get_file_lines(
-                "debian/patches/add-config.patch")
+                "debian/patches/add-config.patch"
+            )
         self.assertEqual(lines[0], b"Description: Created new configure.ac.\n")
         self.assertEqual(lines[1], b"Origin: other\n")
         self.assertEqual(lines[2], b"Last-Update: 2020-09-08\n")
@@ -414,11 +418,9 @@ Arch: all
                 ),
             ]
         )
-        tree.add([
-            "debian/patches",
-            "debian/patches/series",
-            "debian/patches/foo"
-        ])
+        tree.add(
+            ["debian/patches", "debian/patches/series", "debian/patches/foo"]
+        )
         tree.commit("Add patches")
 
         class NewFileFixer:
@@ -472,17 +474,18 @@ Arch: all
     def test_fails(self):
         with self.tree.lock_write():
             result = run_lintian_fixers(
-                self.tree, [FailingFixer("fail", ["some-tag"])],
-                update_changelog=False
+                self.tree,
+                [FailingFixer("fail", ["some-tag"])],
+                update_changelog=False,
             )
         self.assertEqual([], result.success)
         self.assertEqual(
-            {"fail": FixerFailed("Not successful")},
-            result.failed_fixers)
+            {"fail": FixerFailed("Not successful")}, result.failed_fixers
+        )
         with self.tree.lock_read():
             self.assertEqual(
-                [],
-                list(self.tree.iter_changes(self.tree.basis_tree())))
+                [], list(self.tree.iter_changes(self.tree.basis_tree()))
+            )
 
     def test_not_debian_tree(self):
         self.tree.remove("debian/changelog")
@@ -500,8 +503,9 @@ Arch: all
     def test_simple_modify(self):
         with self.tree.lock_write():
             result = run_lintian_fixers(
-                self.tree, [DummyFixer("dummy", ["some-tag"])],
-                update_changelog=False
+                self.tree,
+                [DummyFixer("dummy", ["some-tag"])],
+                update_changelog=False,
             )
             revid = self.tree.last_revision()
         self.assertEqual(
@@ -563,8 +567,8 @@ Arch: all
         self.assertEqual("certain", result.certainty)
         self.assertEqual(2, tree.branch.revno())
         self.assertEqual(
-            tree.get_file_lines("debian/control")[-1],
-            b"a new line\n")
+            tree.get_file_lines("debian/control")[-1], b"a new line\n"
+        )
 
     def test_honors_tree_committer_specified(self):
         tree = self.make_package_tree("git")
@@ -872,7 +876,7 @@ class LintianBrushVersion(TestCase):
         with open("debian/changelog") as f:
             cl = Changelog(f, max_blocks=1)
         package_version = str(cl.version)
-        m = re.match(r'^\d+\.\d+', package_version)
+        m = re.match(r"^\d+\.\d+", package_version)
         assert m is not None
         package_version = m.group(0)
         self.assertEqual(package_version, version_string)
@@ -906,7 +910,8 @@ class GetCommitterTests(TestCaseWithTransport):
         gs.set("email", "Yet Another Committer <yet@example.com>")
         tree = self.make_branch_and_tree(".", format="git")
         self.assertEqual(
-            "Yet Another Committer <yet@example.com>", get_committer(tree))
+            "Yet Another Committer <yet@example.com>", get_committer(tree)
+        )
 
 
 class CertaintySufficientTests(TestCase):
@@ -924,14 +929,6 @@ class CertaintySufficientTests(TestCase):
 
 
 class CertaintyVsConfidenceTests(TestCase):
-    def test_confidence_to_certainty(self):
-        self.assertEqual("certain", confidence_to_certainty(0))
-        self.assertEqual("confident", confidence_to_certainty(1))
-        self.assertEqual("likely", confidence_to_certainty(2))
-        self.assertEqual("possible", confidence_to_certainty(3))
-        self.assertEqual("unknown", confidence_to_certainty(None))
-        self.assertRaises(ValueError, confidence_to_certainty, 2000)
-
     def test_certainty_to_confidence(self):
         self.assertEqual(0, certainty_to_confidence("certain"))
         self.assertEqual(1, certainty_to_confidence("confident"))
@@ -949,7 +946,8 @@ class MinimumCertaintyTests(TestCase):
         self.assertEqual("possible", min_certainty(["possible", "certain"]))
         self.assertEqual("likely", min_certainty(["likely", "certain"]))
         self.assertEqual(
-            "possible", min_certainty(["likely", "certain", "possible"]))
+            "possible", min_certainty(["likely", "certain", "possible"])
+        )
 
 
 class ParseScriptFixerOutputTests(TestCase):
@@ -1002,7 +1000,6 @@ Patch-Name: aname
 
 
 class BaseScriptFixerTests:
-
     script_fixer_cls: Type[ScriptFixer]
 
     build_tree_contents: Any
@@ -1013,10 +1010,12 @@ class BaseScriptFixerTests:
 
     def create_fixer(self, code):
         self.build_tree_contents(
-            [("script.py", "#!" + sys.executable + "\n" + code)])
+            [("script.py", "#!" + sys.executable + "\n" + code)]
+        )
         os.chmod("script.py", 0o755)
         fixer = self.script_fixer_cls(
-            "fixer", ["a-tag"], os.path.abspath("script.py"))
+            "fixer", ["a-tag"], os.path.abspath("script.py")
+        )
         self.assertEqual(os.path.abspath("script.py"), fixer.script_path)
         return fixer
 
@@ -1043,8 +1042,13 @@ foo()
 """
         )
         e = self.assertRaises(
-            FixerScriptFailed, fixer.run, self.test_dir, "blah",
-            Version("0.1"), "buster")
+            FixerScriptFailed,
+            fixer.run,
+            self.test_dir,
+            "blah",
+            Version("0.1"),
+            "buster",
+        )
         self.assertEqual(e.path, fixer.script_path)
         self.assertEqual(e.returncode, 1)
         self.assertEqual(
@@ -1053,18 +1057,14 @@ foo()
         )
 
 
-class ScriptFixerTests(
-        BaseScriptFixerTests, TestCaseWithTransport):  # type: ignore
-
+class ScriptFixerTests(BaseScriptFixerTests, TestCaseWithTransport):  # type: ignore
     test_dir: str
     script_fixer_cls = ScriptFixer
 
 
-class PythonScriptFixerTests(
-        BaseScriptFixerTests, TestCaseWithTransport):  # type: ignore
-
+class PythonScriptFixerTests(BaseScriptFixerTests, TestCaseWithTransport):  # type: ignore
     test_dir: str
-    script_fixer_cls = PythonScriptFixer   # type: ignore
+    script_fixer_cls = PythonScriptFixer  # type: ignore
 
 
 class SelectFixersTests(TestCase):
@@ -1085,8 +1085,10 @@ class SelectFixersTests(TestCase):
 
     def test_missing(self):
         self.assertRaises(
-            KeyError, select_fixers, [DummyFixer("dummy", ["some-tag"])],
-            names=["other"]
+            KeyError,
+            select_fixers,
+            [DummyFixer("dummy", ["some-tag"])],
+            names=["other"],
         )
 
     def test_exclude_missing(self):
