@@ -56,7 +56,6 @@ WATCH_FIX_VALUE = 60
 
 @dataclass
 class WatchCandidate:
-
     watch: Watch
     site: str
     certainty: Optional[str]
@@ -64,25 +63,27 @@ class WatchCandidate:
 
 
 class KeyRetrievalFailed(Exception):
-
     def __init__(self, fingerprints):
         self.fingerprints = fingerprints
 
 
 COMMON_PGPSIGURL_MANGLES = [
-    's/$/.%s/' % ext for ext in ['asc', 'pgp', 'gpg', 'sig', 'sign']]
+    f"s/$/.{ext}/" for ext in ["asc", "pgp", "gpg", "sig", "sign"]
+]
 
 
-SignatureInfo = namedtuple('SignatureInfo', ['is_valid', 'keys', 'mangle'])
+SignatureInfo = namedtuple("SignatureInfo", ["is_valid", "keys", "mangle"])
 
 
-def probe_signature(r, *, pgpsigurlmangle=None, mangles=None,
-                    gpg_context=None):
+def probe_signature(
+    r, *, pgpsigurlmangle=None, mangles=None, gpg_context=None
+):
     """Try to find the signature file for a release."""
     import gpg.errors
 
     if gpg_context is None:
         import gpg
+
         gpg_context = gpg.Context(armor=True)
 
     if mangles is None:
@@ -95,8 +96,8 @@ def probe_signature(r, *, pgpsigurlmangle=None, mangles=None,
         pgpsigurls = [(pgpsigurlmangle, r.pgpsigurl)]
     else:
         pgpsigurls = [
-            (mangle, apply_url_mangle(mangle, r.url))
-            for mangle in mangles]
+            (mangle, apply_url_mangle(mangle, r.url)) for mangle in mangles
+        ]
     for mangle, pgpsigurl in pgpsigurls:
         # Try and download signatures from some predictable locations.
         try:
@@ -104,7 +105,7 @@ def probe_signature(r, *, pgpsigurlmangle=None, mangles=None,
         except urllib.error.HTTPError:
             continue
         except TimeoutError:
-            logging.warning('Timeout error retrieving %s', pgpsigurl)
+            logging.warning("Timeout error retrieving %s", pgpsigurl)
             continue
         sig = resp.read()
         actual = urlopen(r.url).read()
@@ -112,19 +113,21 @@ def probe_signature(r, *, pgpsigurlmangle=None, mangles=None,
             gr = gpg_context.verify(actual, sig)[1]
         except gpg.errors.GPGMEError as e:
             logging.warning(
-                'Error verifying signature %s on %s: %s',
-                pgpsigurl, r.url, e)
+                "Error verifying signature %s on %s: %s", pgpsigurl, r.url, e
+            )
             continue
         except gpg.errors.BadSignatures as e:
-            if str(e).endswith(': No public key'):
+            if str(e).endswith(": No public key"):
                 if not fetch_keys(
-                        [s.fpr for s in e.result.signatures],
-                        home_dir=gpg_context.home_dir):
+                    [s.fpr for s in e.result.signatures],
+                    home_dir=gpg_context.home_dir,
+                ):
                     logging.warning(
-                        'Unable to retrieve keys: %r',
-                        e.result.signatures)
+                        "Unable to retrieve keys: %r", e.result.signatures
+                    )
                     raise KeyRetrievalFailed(
-                        [s.fpr for s in e.result.signatures]) from e
+                        [s.fpr for s in e.result.signatures]
+                    ) from e
                 gr = gpg_context.verify(actual, sig)[1]
             else:
                 raise
@@ -134,19 +137,24 @@ def probe_signature(r, *, pgpsigurlmangle=None, mangles=None,
         for sig in signatures:
             if not sig_valid(sig):
                 logging.warning(
-                    'Signature from %s in %s for %s not valid',
-                    sig.fpr, pgpsigurl, r.url)
+                    "Signature from %s in %s for %s not valid",
+                    sig.fpr,
+                    pgpsigurl,
+                    r.url,
+                )
                 is_valid = False
             else:
                 needed_keys.add(sig.fpr)
         return SignatureInfo(
-            is_valid=is_valid, keys=needed_keys, mangle=mangle)
+            is_valid=is_valid, keys=needed_keys, mangle=mangle
+        )
     else:
         return None
 
 
 def candidates_from_setup_py(
-        path, good_upstream_versions: Set[str], net_access=False):
+    path, good_upstream_versions: Set[str], net_access=False
+):
     certainty = "likely"
     # Import setuptools in case it replaces distutils
     with suppress(ImportError):
@@ -163,18 +171,16 @@ def candidates_from_setup_py(
     project = result.get_name()  # type: ignore
     version = result.get_version()  # type: ignore
     if not project:
-        logging.warning('no project name in setup.py')
+        logging.warning("no project name in setup.py")
         return
     current_version_filenames = None
     if net_access:
         # TODO(jelmer): Use ognibuild.upstream.load_pypi
-        json_url = "https://pypi.python.org/pypi/%s/json" % project
-        logging.info('Getting %s info on pypi (%s)',
-                     project, json_url)
+        json_url = f"https://pypi.python.org/pypi/{project}/json"
+        logging.info("Getting %s info on pypi (%s)", project, json_url)
         pypi_data = _load_json(json_url)
         if pypi_data is None:
-            logging.warning('unable to find project %s on pypi',
-                            project)
+            logging.warning("unable to find project %s on pypi", project)
             return
         if version in pypi_data["releases"]:
             release = pypi_data["releases"][version]
@@ -184,21 +190,18 @@ def candidates_from_setup_py(
                 if d["packagetype"] == "sdist"
             ]
     filename_regex = (
-        r"{project}-(.+)\.(?:zip|tgz|tbz|txz|(?:tar\.(?:gz|bz2|xz)))".format(
-            project=project))
+        rf"{project}-(.+)\.(?:zip|tgz|tbz|txz|(?:tar\.(?:gz|bz2|xz)))"
+    )
     opts = []
     # TODO(jelmer): Set uversionmangle?
     # opts.append('uversionmangle=s/(rc|a|b|c)/~$1/')
     if current_version_filenames:
-        for (fn, has_sig) in current_version_filenames:
+        for fn, has_sig in current_version_filenames:
             if re.match(filename_regex, fn):
                 certainty = "certain"
                 if has_sig:
                     opts.append("pgpsigurlmangle=s/$/.asc/")
-    url = r"https://pypi.debian.net/{project}/{fname_regex}".format(
-        project=project,
-        fname_regex=filename_regex,
-    )
+    url = rf"https://pypi.debian.net/{project}/{filename_regex}"
     # TODO(jelmer): Add pgpsigurlmangle if has_sig==True
     w = Watch(url, opts=opts)
     yield WatchCandidate(w, "pypi", certainty=certainty, preference=1)
@@ -206,20 +209,29 @@ def candidates_from_setup_py(
 
 def find_candidates(path, good_upstream_versions, net_access=False):
     candidates = []
-    if os.path.exists(os.path.join(path, 'setup.py')):
-        candidates.extend(candidates_from_setup_py(
-            os.path.join(path, 'setup.py'), good_upstream_versions,
-            net_access=net_access))
+    if os.path.exists(os.path.join(path, "setup.py")):
+        candidates.extend(
+            candidates_from_setup_py(
+                os.path.join(path, "setup.py"),
+                good_upstream_versions,
+                net_access=net_access,
+            )
+        )
 
-    if os.path.exists(os.path.join(path, 'debian/upstream/metadata')):
-        candidates.extend(candidates_from_upstream_metadata(
-            os.path.join(path, 'debian/upstream/metadata'),
-            good_upstream_versions, net_access=net_access))
+    if os.path.exists(os.path.join(path, "debian/upstream/metadata")):
+        candidates.extend(
+            candidates_from_upstream_metadata(
+                os.path.join(path, "debian/upstream/metadata"),
+                good_upstream_versions,
+                net_access=net_access,
+            )
+        )
 
     def candidate_key(candidate):
         return (
             certainty_to_confidence(candidate.certainty),
-            candidate.preference)
+            candidate.preference,
+        )
 
     candidates.sort(key=candidate_key)
 
@@ -227,7 +239,8 @@ def find_candidates(path, good_upstream_versions, net_access=False):
 
 
 def candidates_from_upstream_metadata(
-        path: str, good_upstream_versions: Set[str], net_access: bool = False):
+    path: str, good_upstream_versions: Set[str], net_access: bool = False
+):
     try:
         with open(path) as f:
             inp = f.read()
@@ -236,38 +249,46 @@ def candidates_from_upstream_metadata(
     else:
         import ruamel.yaml
 
-        code = ruamel.yaml.round_trip_load(inp, preserve_quotes=True)
+        yaml = ruamel.yaml.YAML()
+
+        yaml.preserve_quotes = True
+
+        code = yaml.load(inp)
 
         for field in ["Repository", "X-Download"]:
             try:
-                parsed_url = urlparse(code[field].split(' ')[0])
+                parsed_url = urlparse(code[field].split(" ")[0])
             except KeyError:
                 pass
             else:
                 if parsed_url.hostname == "github.com":
                     yield from guess_github_watch_entry(
-                        parsed_url, good_upstream_versions,
-                        net_access=net_access
+                        parsed_url,
+                        good_upstream_versions,
+                        net_access=net_access,
                     )
                 if parsed_url.hostname == "launchpad.net":
                     yield from guess_launchpad_watch_entry(
-                        parsed_url, good_upstream_versions,
-                        net_access=net_access
+                        parsed_url,
+                        good_upstream_versions,
+                        net_access=net_access,
                     )
 
-        archive = code.get('Archive')
-        if archive == 'CRAN':
-            yield from guess_cran_watch_entry(code['Name'])
+        archive = code.get("Archive")
+        if archive == "CRAN":
+            yield from guess_cran_watch_entry(code["Name"])
 
 
 def guess_cran_watch_entry(name):
-    w = Watch(r'https://cran.r-project.org/src/contrib/%s_([-\d.]*)\.tar\.gz'
-              % name)
+    w = Watch(
+        rf"https://cran.r-project.org/src/contrib/{name}_([-\d.]*)\.tar\.gz"
+    )
     yield WatchCandidate(w, "cran", certainty="likely", preference=0)
 
 
 def guess_launchpad_watch_entry(
-        parsed_url, good_upstream_versions, net_access=False):
+    parsed_url, good_upstream_versions, net_access=False
+):
     if not net_access:
         return
     project = parsed_url.path.strip("/").split("/")[0]
@@ -275,21 +296,26 @@ def guess_launchpad_watch_entry(
     entries = []
     while url:
         response = _load_json(url)
-        entries.extend(response['entries'])
-        url = response.get('next_collection_link')
-    files = _load_json(entries[-1]['files_collection_link'])
-    assert len(files['entries']) > 0
+        entries.extend(response["entries"])
+        url = response.get("next_collection_link")
+    files = _load_json(entries[-1]["files_collection_link"])
+    assert len(files["entries"]) > 0
     # TODO(jelmer): add
-    filepattern = files['entries'][0]['file_link'].split('/')[-2].replace(
-        entries[-1]['version'], '(.*)')
+    filepattern = (
+        files["entries"][0]["file_link"]
+        .split("/")[-2]
+        .replace(entries[-1]["version"], "(.*)")
+    )
     w = Watch(
-        f'https://launchpad.net/{project}/+download',
-        f'https://launchpad.net/{project}/.*/{filepattern}')
+        f"https://launchpad.net/{project}/+download",
+        f"https://launchpad.net/{project}/.*/{filepattern}",
+    )
     yield WatchCandidate(w, "launchpad", certainty="certain", preference=0)
 
 
 def guess_github_watch_entry(
-        parsed_url, good_upstream_versions, net_access=False):
+    parsed_url, good_upstream_versions, net_access=False
+):
     import re
 
     from breezy.branch import Branch
@@ -298,8 +324,11 @@ def guess_github_watch_entry(
         return
     branch = Branch.open(urlunparse(parsed_url))
     tags = branch.tags.get_tag_dict()
-    POSSIBLE_PATTERNS = [r"v(\d\S+)", r"(\d\S+)",
-                         r".*/[vV]?(\d[^\s+]+)\.tar\.gz"]
+    POSSIBLE_PATTERNS = [
+        r"v(\d\S+)",
+        r"(\d\S+)",
+        r".*/[vV]?(\d[^\s+]+)\.tar\.gz",
+    ]
     version_pattern = None
     # TODO(jelmer): Maybe use releases API instead?
     # TODO(jelmer): Automatically added mangling for
@@ -320,14 +349,9 @@ def guess_github_watch_entry(
     (username, project) = parsed_url.path.strip("/").split("/")
     if project.endswith(".git"):
         project = project[:-4]
-    download_url = "https://github.com/{user}/{project}/tags".format(
-        user=username,
-        project=project,
-    )
-    matching_pattern = r".*\/%s\.tar\.gz" % version_pattern
-    opts = [
-        fr"filenamemangle=s/{matching_pattern}/{project}-$1\.tar\.gz/"
-    ]
+    download_url = f"https://github.com/{username}/{project}/tags"
+    matching_pattern = rf".*\/{version_pattern}\.tar\.gz"
+    opts = [rf"filenamemangle=s/{matching_pattern}/{project}-$1\.tar\.gz/"]
     if uversionmangle:
         opts.append(r"uversionmangle=" + ";".join(uversionmangle))
     # TODO(jelmer): Check for GPG
@@ -355,7 +379,7 @@ def _load_json(url):
 def candidates_from_hackage(package, good_upstream_versions, net_access=False):
     if not net_access:
         return
-    url = "https://hackage.haskell.org/package/%s/preferred" % package
+    url = f"https://hackage.haskell.org/package/{package}/preferred"
     versions = _load_json(url)
     if versions is None:
         return
@@ -365,7 +389,7 @@ def candidates_from_hackage(package, good_upstream_versions, net_access=False):
     else:
         return
     download_url = "https://hackage.haskell.org/package/" + package
-    matching_pattern = r".*/%s-(.*).tar.gz" % package
+    matching_pattern = rf".*/{package}-(.*).tar.gz"
     w = Watch(download_url, matching_pattern)
     yield WatchCandidate(w, "hackage", certainty="certain", preference=1)
 
@@ -379,18 +403,18 @@ def fix_old_github_patterns(updater):
         if parsed_url.netloc != "github.com":
             continue
 
-        parts = parsed_url.path.strip('/').split('/')
-        if len(parts) >= 3 and parts[2] in ('tags', 'releases'):  # noqa:SIM114
+        parts = parsed_url.path.strip("/").split("/")
+        if len(parts) >= 3 and parts[2] in ("tags", "releases"):  # noqa:SIM114
             pass
-        elif len(parts) >= 2 and parts[0] == '.*' and parts[1] == 'archive':
+        elif len(parts) >= 2 and parts[0] == ".*" and parts[1] == "archive":
             pass
         else:
             continue
 
-        parts = w.matching_pattern.split('/')
-        if len(parts) > 2 and parts[-2] == 'archive':
-            parts.insert(-1, 'refs/tags')
-        w.matching_pattern = '/'.join(parts)
+        parts = w.matching_pattern.split("/")
+        if len(parts) > 2 and parts[-2] == "archive":
+            parts.insert(-1, "refs/tags")
+        w.matching_pattern = "/".join(parts)
         ret.append(w)
     return ret
 
@@ -404,10 +428,10 @@ def fix_github_releases(updater):
         if parsed_url.netloc != "github.com":
             continue
 
-        parts = parsed_url.path.strip('/').split('/')
-        if len(parts) >= 3 and parts[2] == 'releases':
-            parts[2] = 'tags'
-            parsed_url = parsed_url._replace(path='/'.join(parts))
+        parts = parsed_url.path.strip("/").split("/")
+        if len(parts) >= 3 and parts[2] == "releases":
+            parts[2] = "tags"
+            parsed_url = parsed_url._replace(path="/".join(parts))
             w.url = parsed_url.geturl()
             ret.append(w)
     return ret
@@ -420,15 +444,15 @@ def fix_watch_issues(updater):
     return ret
 
 
-def watch_entries_certainty(entries, source_package,
-                            expected_versions=None,
-                            default_certainty="likely"):
+def watch_entries_certainty(
+    entries, source_package, expected_versions=None, default_certainty="likely"
+):
     certainty = "certain"
     for entry in entries:
         try:
             ret = verify_watch_entry(
-                entry, source_package,
-                expected_versions=expected_versions)
+                entry, source_package, expected_versions=expected_versions
+            )
         except WatchEntryVerificationFailure:
             certainty = min_certainty(["possible", certainty])
         except TemporaryWatchEntryVerficationError:
@@ -448,7 +472,6 @@ class TemporaryWatchEntryVerficationError(Exception):
 
 
 class WatchEntryVerificationStatus:
-
     def __init__(self, entry, releases, missing_versions=None):
         self.entry = entry
         self.releases = {r.version: r for r in releases}
@@ -459,16 +482,16 @@ class WatchEntryVerificationStatus:
 
 
 def verify_watch_entry(
-        entry: Watch, source_package: str,
-        expected_versions: Optional[
-            List[str]] = None) -> WatchEntryVerificationStatus:
+    entry: Watch,
+    source_package: str,
+    expected_versions: Optional[List[str]] = None,
+) -> WatchEntryVerificationStatus:
     try:
-        releases = list(sorted(
-                entry.discover(source_package), reverse=True))
+        releases = list(sorted(entry.discover(source_package), reverse=True))
     except urllib.error.HTTPError as e:
         logging.warning(
-            'HTTP error accessing discovery URL %s: %s.',
-            e.geturl(), e)
+            "HTTP error accessing discovery URL %s: %s.", e.geturl(), e
+        )
         if (e.status or 0) // 100 == 5:
             # If the server is unhappy, then the entry could still be valid.
             raise TemporaryWatchEntryVerficationError(str(e)) from e
@@ -481,44 +504,56 @@ def verify_watch_entry(
     found_versions = {str(r.version) for r in releases}
     missing_versions = set(expected_versions) - found_versions
     return WatchEntryVerificationStatus(
-        entry, releases=releases, missing_versions=missing_versions)
+        entry, releases=releases, missing_versions=missing_versions
+    )
 
 
 def report_fatal(code: str, description: str, context=None, hint=None) -> None:
-    if os.environ.get('SVP_API') == '1':
-        with open(os.environ['SVP_RESULT'], 'w') as f:
-            json.dump({
-                'result_code': code,
-                'description': description,
-                'context': context}, f)
-    logging.fatal('%s', description)
+    if os.environ.get("SVP_API") == "1":
+        with open(os.environ["SVP_RESULT"], "w") as f:
+            json.dump(
+                {
+                    "result_code": code,
+                    "description": description,
+                    "context": context,
+                },
+                f,
+            )
+    logging.fatal("%s", description)
     if hint:
-        logging.info('%s', hint)
+        logging.info("%s", hint)
 
 
 def verify_watch_file(watch_file, source_package, expected_versions):
     ret = []
-    for entry in getattr(watch_file, 'entries', []):
-        ret.append(verify_watch_entry(
-            entry, source_package, expected_versions))
+    for entry in getattr(watch_file, "entries", []):
+        ret.append(
+            verify_watch_entry(entry, source_package, expected_versions)
+        )
     return ret
 
 
 def svp_context(status, site):
-    return [{
-        'entries': {
-            'text': str(entry_status.entry),
-            'site': entry_site,
-            'releases': {
-                str(r.version): {
-                    'url': r.url,
-                } for r in entry_status.releases.values()
-            },
-            'missing_versions':
-                [str(x) for x in entry_status.missing_versions]
+    return [
+        {
+            "entries": {
+                "text": str(entry_status.entry),
+                "site": entry_site,
+                "releases": {
+                    str(r.version): {
+                        "url": r.url,
+                    }
+                    for r in entry_status.releases.values()
+                },
+                "missing_versions": [
+                    str(x) for x in entry_status.missing_versions
+                ],
+            }
         }
-    } for entry_status, entry_site in zip(
-        status or [], site or [None] * len(status or []))]
+        for entry_status, entry_site in zip(
+            status or [], site or [None] * len(status or [])
+        )
+    ]
 
 
 _changelog_policy_noted = False
@@ -600,10 +635,13 @@ def main():  # noqa: C901
     parser.add_argument(
         "--force",
         help="Force regenerating watch file, even if it the current one works",
-        action="store_true")
+        action="store_true",
+    )
     parser.add_argument(
-        "--no-verify", action="store_true",
-        help="Do not verify that the new watch file works")
+        "--no-verify",
+        action="store_true",
+        help="Do not verify that the new watch file works",
+    )
     parser.add_argument(
         "--disable-net-access",
         help="Do not probe external services.",
@@ -616,19 +654,20 @@ def main():  # noqa: C901
     if args.debug:
         logging.basicConfig(level=logging.DEBUG)
     else:
-        logging.basicConfig(level=logging.INFO, format='%(message)s')
+        logging.basicConfig(level=logging.INFO, format="%(message)s")
 
     wt, subpath = WorkingTree.open_containing(args.directory)
     if args.identity:
-        logging.info('%s', get_committer(wt))
+        logging.info("%s", get_committer(wt))
         return 0
 
     with wt.lock_write():
         try:
             check_clean_tree(wt, wt.basis_tree(), subpath)
         except WorkspaceDirty:
-            logging.info("%s: Please commit pending changes first.",
-                         wt.basedir)
+            logging.info(
+                "%s: Please commit pending changes first.", wt.basedir
+            )
             return 1
 
         update_changelog = args.update_changelog
@@ -663,78 +702,95 @@ def main():  # noqa: C901
 
         status = None
         try:
-            with WatchEditor(allow_reformatting=allow_reformatting,
-                             allow_missing=False,
-                             ) as updater:
+            with WatchEditor(
+                allow_reformatting=allow_reformatting,
+                allow_missing=False,
+            ) as updater:
                 if not args.force:
                     try:
                         status = verify_watch_file(
-                            updater.watch_file, package, expected_versions)
-                    except (TemporaryWatchEntryVerficationError,
-                            WatchEntryVerificationFailure):
+                            updater.watch_file, package, expected_versions
+                        )
+                    except (
+                        TemporaryWatchEntryVerficationError,
+                        WatchEntryVerificationFailure,
+                    ):
                         status = [None]
                     if status and all(status):
-                        hint = (
-                            'Releases {} can be found with watch entry {}'
-                            .format(
-                                ', '.join(sorted(list(
-                                    status[0].releases.keys()), reverse=True)),
-                                status[0].entry))
+                        hint = "Releases {} can be found with watch entry {}".format(
+                            ", ".join(
+                                sorted(
+                                    list(status[0].releases.keys()),
+                                    reverse=True,
+                                )
+                            ),
+                            status[0].entry,
+                        )
                         report_fatal(
-                            'nothing-to-do',
-                            'Existing watch file has valid entries',
+                            "nothing-to-do",
+                            "Existing watch file has valid entries",
                             context=svp_context(status, site=None),
-                            hint=hint)
+                            hint=hint,
+                        )
                         return 0
                     fix_watch_issues(updater)
                     try:
                         status = verify_watch_file(
-                            updater.watch_file, package, expected_versions)
+                            updater.watch_file, package, expected_versions
+                        )
                     except WatchEntryVerificationFailure:
                         status = [None]
                     except TemporaryWatchEntryVerficationError as e:
-                        report_fatal('temporary-verification-error', str(e))
+                        report_fatal("temporary-verification-error", str(e))
                         return 1
                 if status is None or not all(status):
                     candidates = find_candidates(
-                        '.', good_upstream_versions,
-                        net_access=not args.disable_net_access)
+                        ".",
+                        good_upstream_versions,
+                        net_access=not args.disable_net_access,
+                    )
                     if len(candidates) == 0:
                         report_fatal(
-                            'no-download-urls-found',
-                            'No candidates for the watch file were found')
+                            "no-download-urls-found",
+                            "No candidates for the watch file were found",
+                        )
                         return 1
                     updater.allow_reformatting = True
                     updater.watch_file.entries = [candidates[0].watch]
                     site = [candidates[0].site]
                     status = None
-                    summary = f'Update watch file from {site[0]}'
+                    summary = f"Update watch file from {site[0]}"
                 else:
                     site = None
-                    summary = 'Fixed watch file'
+                    summary = "Fixed watch file"
             specific_files = updater.changed_files
         except FileNotFoundError:
             candidates = find_candidates(
-                '.', good_upstream_versions,
-                net_access=not args.disable_net_access)
+                ".",
+                good_upstream_versions,
+                net_access=not args.disable_net_access,
+            )
             wf = WatchFile()
             if len(candidates) == 0:
                 report_fatal(
-                    'no-download-urls-found',
-                    'No candidates for the watch file were found')
+                    "no-download-urls-found",
+                    "No candidates for the watch file were found",
+                )
                 return 1
             wf.entries.append(candidates[0].watch)
             site = [candidates[0].site]
 
-            with open('debian/watch', 'w') as f:
+            with open("debian/watch", "w") as f:
                 wf.dump(f)
             status = None
-            summary = f'Added watch file from {site}'
-            specific_files = ['debian/watch']
+            summary = f"Added watch file from {site}"
+            specific_files = ["debian/watch"]
         except FormattingUnpreservable as e:
-            report_fatal('formatting-unpreservable',
-                         "Unable to preserve formatting of %s" % e.path)
-            if hasattr(e, 'diff'):  # debmutate >= 0.64
+            report_fatal(
+                "formatting-unpreservable",
+                f"Unable to preserve formatting of {e.path}",
+            )
+            if hasattr(e, "diff"):  # debmutate >= 0.64
                 sys.stderr.writelines(e.diff())
             return 1
 
@@ -742,32 +798,34 @@ def main():  # noqa: C901
             with WatchEditor() as updater:
                 try:
                     status = verify_watch_file(
-                        updater.watch_file, package, expected_versions)
+                        updater.watch_file, package, expected_versions
+                    )
                 except WatchEntryVerificationFailure as e:
                     report_fatal(
-                        'verification-failed',
-                        'Unable to verify watch entry: %s'
-                        % e)
+                        "verification-failed",
+                        f"Unable to verify watch entry: {e}",
+                    )
                     return 1
                 except TemporaryWatchEntryVerficationError as e:
                     report_fatal(
-                        'temporary-verification-error',
-                        'Unable to verify watch entry: %s'
-                        % e)
+                        "temporary-verification-error",
+                        f"Unable to verify watch entry: {e}",
+                    )
                     return 1
                 if not status or not all(status):
                     report_fatal(
-                        'verification-failed',
-                        'Unable to watch entries; missing versions: %r'
-                        % status[0].missing_versions,
-                        context=svp_context(status, site))
+                        "verification-failed",
+                        f"Unable to watch entries; missing versions: {status[0].missing_versions!r}",
+                        context=svp_context(status, site),
+                    )
                     return 1
 
         if update_changelog is None:
             from .detect_gbp_dch import guess_update_changelog
 
             dch_guess = guess_update_changelog(
-                wt, os.path.join(subpath, 'debian'), cl)
+                wt, os.path.join(subpath, "debian")
+            )
             if dch_guess:
                 update_changelog = dch_guess.update_changelog
                 _note_changelog_policy(update_changelog, dch_guess.explanation)
@@ -795,24 +853,31 @@ def main():  # noqa: C901
 
     if svp_enabled():
         with open(os.environ["SVP_RESULT"], "w") as f:
-            json.dump({
-                "description": summary,
-                "context": svp_context(status, site),
-                "value": WATCH_FIX_VALUE,
-            }, f)
+            json.dump(
+                {
+                    "description": summary,
+                    "context": svp_context(status, site),
+                    "value": WATCH_FIX_VALUE,
+                },
+                f,
+            )
 
-    logging.info('%s', summary)
+    logging.info("%s", summary)
 
     if status is not None:
-        logging.info('Releases {} can be found with new watch entry {}'.format(
-            ', '.join(sorted(list(
-                status[0].releases.keys()), reverse=True)),
-            status[0].entry))
+        logging.info(
+            "Releases {} can be found with new watch entry {}".format(
+                ", ".join(
+                    sorted(list(status[0].releases.keys()), reverse=True)
+                ),
+                status[0].entry,
+            )
+        )
 
     return 0
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     import sys
 
     sys.exit(main())
