@@ -2,7 +2,6 @@ use breezyshim::dirty_tracker::DirtyTracker;
 use breezyshim::tree::{CommitError, Error as TreeError, WorkingTree};
 use debian_analyzer::debmutateshim::{
     format_relations, parse_relations, ControlEditor, ControlLikeEditor, Deb822Paragraph,
-    ParsedRelation,
 };
 use debian_analyzer::{
     add_changelog_entry, apply_or_revert, certainty_sufficient, get_committer, ApplyError,
@@ -11,9 +10,8 @@ use debian_analyzer::{
 use debversion::Version;
 use lazy_regex::regex_captures;
 use lazy_static::lazy_static;
-use pyo3::PyErr;
 use reqwest::blocking::Client;
-use serde::{Deserialize, Serialize};
+use serde::Deserialize;
 use serde_yaml::from_value;
 use std::collections::HashMap;
 use std::error::Error;
@@ -140,8 +138,7 @@ mod tests {
     #[test]
     fn test_some_entries() {
         let hints = parse_multiarch_hints(
-            r#"\
-format: multiarch-hints-1.0
+            r#"format: multiarch-hints-1.0
 hints:
 - binary: coinor-libcoinmp-dev
   description: coinor-libcoinmp-dev conflicts on ...
@@ -156,7 +153,7 @@ hints:
         assert_eq!(
             hints,
             vec![Hint {
-                binary: "coinor-libcoimp-dev".to_string(),
+                binary: "coinor-libcoinmp-dev".to_string(),
                 description: "coinor-libcoinmp-dev conflicts on ...".to_string(),
                 link: "https://wiki.debian.org/MultiArch/Hints#file-conflict".to_string(),
                 severity: Severity::High,
@@ -422,7 +419,9 @@ fn changes_by_description(changes: &[Change]) -> HashMap<String, Vec<String>> {
 pub enum OverallError {
     TreeError(TreeError),
     NotDebianPackage(std::path::PathBuf),
-    Python(PyErr),
+    Other(String),
+    Python(pyo3::PyErr),
+    NoWhoami,
     NoChanges,
 }
 
@@ -434,7 +433,9 @@ impl std::fmt::Display for OverallError {
             }
             OverallError::TreeError(e) => write!(f, "{}", e),
             OverallError::Python(e) => write!(f, "{}", e),
+            OverallError::NoWhoami => write!(f, "No committer configured."),
             OverallError::NoChanges => write!(f, "No changes to apply."),
+            OverallError::Other(e) => write!(f, "{}", e),
         }
     }
 }
@@ -447,16 +448,11 @@ impl From<TreeError> for OverallError {
     }
 }
 
-impl From<PyErr> for OverallError {
-    fn from(e: PyErr) -> Self {
-        OverallError::Python(e)
-    }
-}
-
 impl From<CommitError> for OverallError {
     fn from(e: CommitError) -> Self {
         match e {
             CommitError::PointlessCommit => OverallError::NoChanges,
+            CommitError::NoWhoami => OverallError::NoWhoami,
             CommitError::Other(e) => OverallError::Python(e),
         }
     }
@@ -466,7 +462,7 @@ impl From<ChangelogError> for OverallError {
     fn from(e: ChangelogError) -> Self {
         match e {
             ChangelogError::NotDebianPackage(p) => OverallError::NotDebianPackage(p),
-            ChangelogError::Python(e) => OverallError::Python(e),
+            ChangelogError::Python(e) => OverallError::Other(e.to_string()),
         }
     }
 }
@@ -486,7 +482,7 @@ pub fn apply_multiarch_hints(
     let (changes, _tree_changes, mut specific_files) = match apply_or_revert(
         local_tree,
         subpath,
-        &basis_tree,
+        basis_tree.as_ref(),
         dirty_tracker,
         |path| -> Result<Vec<Change>, ()> {
             let mut changes: Vec<Change> = vec![];
