@@ -3,6 +3,7 @@ use clap::Parser;
 use std::io::Write as _;
 
 #[derive(Parser)]
+#[command(author, version)]
 struct Args {
     /// Be verbose
     #[clap(long)]
@@ -28,7 +29,7 @@ fn main() {
         )
         .init();
 
-    breezyshim::init();
+    breezyshim::init().unwrap();
 
     let (wt, subpath) = WorkingTree::open_containing(&args.directory).unwrap();
     let debian_path = if debian_analyzer::control_files_in_root(&wt, subpath.as_path()) {
